from crypt import methods
from socket import send_fds
from flask import Flask, send_from_directory
from flask_cors import CORS, cross_origin
from flask_restful import Api
from resources.dictionary import Dictionary
from resources.obtainCrypto import ObtainCrypto, ObtainCryptoList
from resources.rooms import Room, RoomsList
from resources.themes import Theme, ThemesList
from resources.transactions import Transaction, TransactionsList

from resources.user import Users, UserList
from resources.wordleSpanish import WordleSpanish, WordleSpanishList
from resources.wordleWord import WordleWord, WordleWordList
from resources.bets import Bet, BetsList


app = Flask(__name__, static_folder='wordle-crypto/build', static_url_path='')
api = Api(app)
CORS(app, resources={r'/*': {"origins": "*", "allow_headers": "*", "expose_headers": "*"}})


@app.route('/api', methods=['GET'])
@cross_origin(headers=['Content- Type','Authorization'])
def index():
    return {
        "tutorial": "Flask React Heroku"
    }

@app.route('/')
@app.route('/home')
@app.route('/wordle')
@app.route('/send-ethereum')
@app.route('/store')
@app.route('/how-to-play')
@app.route('/wordle-random')
@app.route('/multiplayer')
@app.route('/join-room')
@app.route('/wordle-multiplayer')
@app.route('/obtain-cryptos')
@app.route('/about')
def serve():
    return send_from_directory(app.static_folder, 'index.html')

api.add_resource(Users, '/user','/user/address/<string:address>')
api.add_resource(UserList, '/users')

api.add_resource(WordleWord, '/wordle-word','/wordle-word/language/<string:language>')
api.add_resource(WordleWordList, '/wordle-words')

api.add_resource(Bet, '/bet','/bet/date/<string:bet_date>')
api.add_resource(BetsList, '/bets')

api.add_resource(Transaction, '/transaction','/transaction/sender/<string:sender>')
api.add_resource(TransactionsList, '/transactions')

api.add_resource(Dictionary, '/dictionary/word/<string:word>') 

api.add_resource(WordleSpanish, '/wordle-spanish','/wordle-spanish/address/<string:address>')
api.add_resource(WordleSpanishList, '/wordle-spanish-list')

api.add_resource(Theme, '/theme','/theme/id/<string:id>')
api.add_resource(ThemesList, '/themes')

api.add_resource(ObtainCrypto, '/obtain-crypto','/obtain-crypto/address/<string:address>')
api.add_resource(ObtainCryptoList, '/obtain-crypto-list')

api.add_resource(Room, '/room','/room/id/<string:id>')
api.add_resource(RoomsList, '/rooms')

if __name__ == '__main__':
    app.run(port=5000, debug=True)