
from google.cloud import firestore

from db import db


class BetModel:
    __coll_ref__ = db.collection(u'{}'.format('bets'))
    __doc_ref__ = None

    def __init__(self, bet_date= None, amount_eth = None, users = None, current_total_eth= None, doc_ref=None):
    
        self.bet_date = bet_date
        self.amount_eth = amount_eth
        self.users = list()
        self.current_total_eth = str(float(0))
        if len(self.users) != 0: self.current_total_eth = str(float(len(self.users)) * float(self.amount_eth))
        #print(self.current_total_eth)
        self.__doc_ref__ = doc_ref
        if self.__doc_ref__:
            
            try:
                doc = doc_ref.get()
                if doc.exists:
                    data = doc.to_dict()
                    self.bet_date = data[u'bet_date']
                    self.amount_eth = data[u'amount_eth']
                    self.users = data[u'users']
                    self.current_total_eth = data[u'current_total_eth']
            except Exception as e:
                raise Exception("document does not exists! Error type {}".format(type(e)))

    @property
    # would rise an exception if document is not yet created
    def id(self):
        return self.__doc_ref__.id if self.__doc_ref__ else None

    @property
    # would rise an exception if document is not yet created
    def parent(self):
        return self.__coll_ref__.id if self.__coll_ref__ else None

    @property
    def exists(self):
        return self.__doc_ref__.get().exists if self.__doc_ref__ else False

    # Create new document -- private method
    def __create(self):
        if self.__doc_ref__ is None:
            self.__doc_ref__ = self.__coll_ref__.document()
            my_json = self.json()
            self.__doc_ref__.set(my_json[self.id])
            return my_json
        return self.json()

    def json(self):
        return {
            u'{}'.format(self.id): {
                u'id': u'{}'.format(str(self.id)),
                u'bet_date': u'{}'.format(str(self.bet_date)),
                u'amount_eth': u'{}'.format(str(self.amount_eth)),
                u'users': self.users,
                u'current_total_eth': self.current_total_eth
            }
        }

    def save_to_db(self):
        '''
        Create new bet
        :return: json of new created bet
        '''
        return self.__create()

    def delete_from_db(self):
        '''
        if a bet exists then delete otherwise we don't want to let the user delete a non existing bet
        :return: void
        '''
        if self.exists:
            self.__doc_ref__.delete()
            self.__doc_ref__ = None

    def update_from_db(self, bet_date=None, amount_eth=None, users=None, current_total_eth= None):
        # if it's already created then update
        if self.exists:
            if bet_date:
                self.bet_date = bet_date
                self.__doc_ref__.update({u'bet_date': u'{}'.format(bet_date)})
            if amount_eth:
                self.amount_eth = amount_eth
                self.__doc_ref__.update({u'amount_eth': u'{}'.format(amount_eth)})
            if users:
                self.users = users
                self.__doc_ref__.update({u'users': u'{}'.format(users)})
            if current_total_eth:
                self.current_total_eth = current_total_eth
                self.__doc_ref__.update({u'current_total_eth': u'{}'.format(current_total_eth)})

    @classmethod
    def get_all(cls):
        docs = cls.__coll_ref__.stream()
        ret = dict()
        for doc in docs:
            ret[doc.id] = doc.to_dict()
            # ret[doc.id]['current_total_eth'] = len(doc.to_dict()['users']) * float(doc.get().to_dict()['amount_eth'])
        return ret

    @classmethod
    def find_by_id(cls, id):
        #print(id)
        doc_ref = cls.__coll_ref__.document(u'{}'.format(id))
        #print(doc_ref)
        return BetModel(doc_ref=doc_ref)

    @classmethod
    def update_by_id(cls, id, bet_date=None, amount_eth=None, users=None, current_total_eth=None):
        #print(id)
        bet = BetModel.find_by_id(id)
        #print(bet)
        if bet.exists:
            bet.update_from_db(bet_date=bet_date, amount_eth=amount_eth, users=users, current_total_eth=current_total_eth)
            return bet
    
    @classmethod
    def delete_by_id(cls, id):
        bet = BetModel.find_by_id(id)
        if bet.exists:
            bet.delete_from_db()

    @classmethod
    def find_by_date(cls, bet_date):
        docs = cls.__coll_ref__.where('bet_date', '==', bet_date).stream()
        ret = dict()
        for doc in docs:
            ret[doc.id] = doc.to_dict()
        return ret

    @classmethod
    def add_user_to_bet(cls, id, address):
        try:
            doc = cls.__coll_ref__.document(id)
            if doc.get().exists:
                docdict = doc.get().to_dict()
                if address in docdict['users']:
                    raise Exception("The user is already in this bet")
                else:
                    doc.update({u'users': firestore.ArrayUnion([address])})
                    #print("a")
                    doc.update({u'current_total_eth': str(len(doc.get().to_dict()['users']) * float(doc.get().to_dict()['amount_eth']))})
                    #print("a")
            else:
                raise Exception("Document does not exists!")
        except Exception as e:
            raise Exception(e)

    @classmethod
    def delete_user_from_bet(cls, id, address):
        try:
            doc = cls.__coll_ref__.document(id)
            if doc.get().exists:
                docdict = doc.get().to_dict()
                if address in docdict['users']:
                    doc.update({u'users': firestore.ArrayRemove([address])})
                    doc.update({u'current_total_eth': str(float(len(doc.get().to_dict()['users'])) * float(doc.get().to_dict()['amount_eth']))})
                else:
                    raise Exception("The user is not in this bet")
            else:
                raise Exception("Document does not exists!")
        except Exception as e:
            raise Exception(e)