
import json
from google.cloud import firestore

from db import db


class ObtainCryptoModel:
    __coll_ref__ = db.collection(u'{}'.format('obtain-crypto'))
    __doc_ref__ = None

    def __init__(self, user = None, amount_eth = None, date = None, doc_ref=None):
        self.user = user
        self.amount_eth = amount_eth
        self.date = date
        self.__doc_ref__ = doc_ref
        if self.__doc_ref__:
            try:
                doc = doc_ref.get()
                if doc.exists:
                    data = doc.to_dict()
                    self.user = data[u'user']
                    self.amount_eth = data[u'amount_eth']
                    self.date = data[u'date']
            except Exception as e:
                raise Exception("document does not exists! Error type {}".format(type(e)))

    @property
    # would rise an exception if document is not yet created
    def id(self):
        return self.__doc_ref__.id if self.__doc_ref__ else None

    @property
    # would rise an exception if document is not yet created
    def parent(self):
        return self.__coll_ref__.id if self.__coll_ref__ else None

    @property
    def exists(self):
        return self.__doc_ref__.get().exists if self.__doc_ref__ else False

    # Create new document -- private method
    def __create(self):
        if self.__doc_ref__ is None:
            self.__doc_ref__ = self.__coll_ref__.document()
            my_json = self.json()
            self.__doc_ref__.set(my_json[self.id])
            return my_json
        return self.json()

    def json(self):
        return {
            u'{}'.format(self.id): {
                u'id': u'{}'.format(str(self.id)),
                u'user': u'{}'.format(str(self.user)),
                u'amount_eth': u'{}'.format(str(self.amount_eth)),
                u'date': u'{}'.format(str(self.date))
            }
        }

    def save_to_db(self):
        '''
        Create a new request to obtain crypto
        :return: json of new created request to obtain crypto
        '''
        return self.__create()

    def delete_from_db(self):
        '''
        if a wordle spanish exists then delete otherwise we don't want to let the user delete a non existing request to obtain crypto
        :return: void
        '''
        if self.exists:
            self.__doc_ref__.delete()
            self.__doc_ref__ = None

    @classmethod
    def get_all(cls):
        docs = cls.__coll_ref__.stream()
        ret = dict()
        for doc in docs:
            ret[doc.id] = doc.to_dict()
        return ret
    
    @classmethod
    def delete_all(cls):
        docs = cls.__coll_ref__.stream()
        for doc in docs:
            ObtainCryptoModel.find_by_id(doc.id).delete_from_db()

    @classmethod
    def find_by_id(cls, id):
        doc_ref = cls.__coll_ref__.document(u'{}'.format(id))
        return ObtainCryptoModel(doc_ref=doc_ref)
    
    @classmethod
    def delete_by_id(cls, id):
        user_request = ObtainCryptoModel.find_by_id(id)
        if user_request.exists:
            user_request.delete_from_db()

    @classmethod
    def find_by_user(cls, user):
        docs = cls.__coll_ref__.where('user', '==', user).stream()
        ret = dict()
        for doc in docs:
            ret[doc.id] = doc.to_dict()
        return ret
    
    @classmethod
    def get_id_by_user(cls, user):
        docs = cls.__coll_ref__.where('user', '==', user).stream()
        ret = dict()
        for doc in docs:
            return doc.id
        return ret
