
from heapq import merge
from operator import add
from pickle import TRUE
from google.cloud import firestore

from db import db


class RoomModel:
    __coll_ref__ = db.collection(u'{}'.format('rooms'))
    __doc_ref__ = None

    def __init__(self, amount_eth = None, users = None, current_total_eth= None, word = None, host = None, started = None, doc_ref=None):
    
        self.word = word
        self.amount_eth = amount_eth
        self.users = dict()
        self.current_total_eth = str(float(0))
        if len(self.users) != 0: self.current_total_eth = str(float(len(self.users.keys())) * float(self.amount_eth))
        #print(self.current_total_eth)
        self.host = host
        self.started = False
        self.num_winners = 0
        self.__doc_ref__ = doc_ref
        if self.__doc_ref__:
            
            try:
                doc = doc_ref.get()
                if doc.exists:
                    data = doc.to_dict()
                    self.word = data[u'word']
                    self.amount_eth = data[u'amount_eth']
                    self.users = data[u'users']
                    self.current_total_eth = data[u'current_total_eth']
                    self.host = data[u'host']
                    self.started = data[u'started']
                    self.num_winners = data[u'num_winners']
            except Exception as e:
                raise Exception("document does not exists! Error type {}".format(type(e)))

    @property
    # would rise an exception if document is not yet created
    def id(self):
        return self.__doc_ref__.id if self.__doc_ref__ else None

    @property
    # would rise an exception if document is not yet created
    def parent(self):
        return self.__coll_ref__.id if self.__coll_ref__ else None

    @property
    def exists(self):
        return self.__doc_ref__.get().exists if self.__doc_ref__ else False

    # Create new document -- private method
    def __create(self):
        if self.__doc_ref__ is None:
            self.__doc_ref__ = self.__coll_ref__.document()
            my_json = self.json()
            self.__doc_ref__.set(my_json[self.id])
            return my_json
        return self.json()

    def json(self):
        return {
            u'{}'.format(self.id): {
                u'id': u'{}'.format(str(self.id)),
                u'word': u'{}'.format(str(self.word)),
                u'amount_eth': u'{}'.format(str(self.amount_eth)),
                u'users': self.users,
                u'current_total_eth': self.current_total_eth,
                u'host': u'{}'.format(str(self.host)),
                u'started': self.started,
                u'num_winners': self.num_winners
            }
        }

    def save_to_db(self):
        '''
        Create new room
        :return: json of new created room
        '''
        return self.__create()

    def delete_from_db(self):
        '''
        if a room exists then delete otherwise we don't want to let the user delete a non existing room
        :return: void
        '''
        if self.exists:
            self.__doc_ref__.delete()
            self.__doc_ref__ = None

    def update_from_db(self, word=None, amount_eth=None, users=None, current_total_eth= None, started=None):
        # if it's already created then update
        if self.exists:
            if word:
                self.word = word
                self.__doc_ref__.update({u'word': u'{}'.format(word)})
            if started:
                self.started = started
                self.__doc_ref__.update({'started': started})
            if amount_eth:
                self.amount_eth = amount_eth
                self.__doc_ref__.update({u'amount_eth': u'{}'.format(amount_eth)})
            if users:
                self.users = users
                self.__doc_ref__.update({u'users': u'{}'.format(users)})
            if current_total_eth:
                self.current_total_eth = current_total_eth
                self.__doc_ref__.update({u'current_total_eth': u'{}'.format(current_total_eth)})

    @classmethod
    def get_all(cls):
        docs = cls.__coll_ref__.stream()
        ret = dict()
        for doc in docs:
            ret[doc.id] = doc.to_dict()
            # ret[doc.id]['current_total_eth'] = len(doc.to_dict()['users']) * float(doc.get().to_dict()['amount_eth'])
        return ret

    @classmethod
    def find_by_id(cls, id):
        #print(id)
        doc_ref = cls.__coll_ref__.document(u'{}'.format(id))
        #print(doc_ref)
        return RoomModel(doc_ref=doc_ref)

    @classmethod
    def update_by_id(cls, id, word=None, amount_eth=None, users=None, current_total_eth=None, started = None):
        #print(id)
        room = RoomModel.find_by_id(id)
        #print(bet)
        if room.exists:
            room.update_from_db(word=word, amount_eth=amount_eth, users=users, current_total_eth=current_total_eth, started=started)
            return room
    
    @classmethod
    def delete_by_id(cls, id):
        room = RoomModel.find_by_id(id)
        if room.exists:
            room.delete_from_db()

    @classmethod
    def add_user_to_room(cls, id, address):
        try:
            doc = cls.__coll_ref__.document(id)
            if doc.get().exists:
                docdict = list(doc.get().to_dict()["users"].keys())
                #print(docdict)
                #print(address in docdict)
                if address in docdict:
                    raise Exception("The user is already in this room")
                else:
                    #print("a")
                    user = {address: False}
                    doc.set({u'users': user}, merge = True)
                    #print("a")
                    doc.update({u'current_total_eth': str(len(doc.get().to_dict()["users"].keys()) * float(doc.get().to_dict()['amount_eth']))})
                    #print("a")
            else:
                raise Exception("Document does not exists!")
        except Exception as e:
            raise Exception(e)

    @classmethod
    def set_user_played_from_room(cls, id, address):
        try:
            doc = cls.__coll_ref__.document(id)
            if doc.get().exists:
                docdict = list(doc.get().to_dict()["users"].keys())
                if not address in docdict:
                    raise Exception("The user is not in this room")
                else:
                    user = {address: True}
                    doc.set({u'users': user}, merge = True)
                    doc.set({u'num_winners': int(doc.get().to_dict()["num_winners"]) + 1}, merge = True)
                    #print("num_winners =" + str(doc.get().to_dict()["num_winners"]))
            else:
                raise Exception("Document does not exists!")
        except Exception as e:
            raise Exception(e)
