
from google.cloud import firestore

from db import db


class ThemesModel:
    __coll_ref__ = db.collection(u'{}'.format('themes'))
    __doc_ref__ = None

    def __init__(self, name = None, color = None, priceETH = None, doc_ref=None):
        self.name = name
        self.color = color
        self.priceETH = priceETH
        self.__doc_ref__ = doc_ref
        if self.__doc_ref__:
            try:
                doc = doc_ref.get()
                if doc.exists:
                    data = doc.to_dict()
                    self.name = data[u'name']
                    self.color = data[u'color']
                    self.priceETH = data[u'priceETH']
            except Exception as e:
                raise Exception("document does not exists! Error type {}".format(type(e)))

    @property
    # would rise an exception if document is not yet created
    def id(self):
        return self.__doc_ref__.id if self.__doc_ref__ else None

    @property
    # would rise an exception if document is not yet created
    def parent(self):
        return self.__coll_ref__.id if self.__coll_ref__ else None

    @property
    def exists(self):
        return self.__doc_ref__.get().exists if self.__doc_ref__ else False

    # Create new document -- private method
    def __create(self):
        if self.__doc_ref__ is None:
            self.__doc_ref__ = self.__coll_ref__.document()
            my_json = self.json()
            self.__doc_ref__.set(my_json[self.id])
            return my_json
        return self.json()

    def json(self):
        return {
            u'{}'.format(self.id): {
                u'id': u'{}'.format(str(self.id)),
                u'name': u'{}'.format(str(self.name)),
                u'color': u'{}'.format(str(self.color)),
                u'priceETH': u'{}'.format(str(self.priceETH)),
            }
        }

    def save_to_db(self):
        '''
        Create new them
        :return: json of new created theme
        '''
        return self.__create()

    def delete_from_db(self):
        '''
        if a them exists then delete otherwise we don't want to let the user delete a non existing theme
        :return: void
        '''
        if self.exists:
            self.__doc_ref__.delete()
            self.__doc_ref__ = None

    def update_from_db(self, name=None, color=None, priceETH=None):
        # if it's already created then update
        if self.exists:
            if name:
                self.name = name
                self.__doc_ref__.update({u'name': u'{}'.format(name)})
            if color:
                self.color = color
                self.__doc_ref__.update({u'color': u'{}'.format(color)})
            if priceETH:
                self.priceETH = priceETH
                self.__doc_ref__.update({u'priceETH': u'{}'.format(priceETH)})

    @classmethod
    def get_all(cls):
        docs = cls.__coll_ref__.stream()
        ret = dict()
        for doc in docs:
            ret[doc.id] = doc.to_dict()
        return ret

    @classmethod
    def find_by_id(cls, id):
        doc_ref = cls.__coll_ref__.document(u'{}'.format(id))
        return ThemesModel(doc_ref=doc_ref)

    @classmethod
    def update_by_id(cls, id, name, color, priceETH):
        theme = ThemesModel.find_by_id(id)
        if theme.exists:
            theme.update_from_db(name=name, color=color, priceETH=priceETH)
            return theme
    
    @classmethod
    def delete_by_id(cls, id):
        theme = ThemesModel.find_by_id(id)
        if theme.exists:
            theme.delete_from_db()

    @classmethod
    def find_by_name(cls, name):
        docs = cls.__coll_ref__.where('name', '==', name).stream()
        ret = dict()
        for doc in docs:
            ret[doc.id] = doc.to_dict()
        return ret