
from google.cloud import firestore

from db import db


class TransactionModel:
    __coll_ref__ = db.collection(u'{}'.format('transactions'))
    __doc_ref__ = None

    def __init__(self, hash= None, type = None, sender = None, receiver = None, amount_eth = None, date = None, doc_ref=None):
        self.hash = hash
        self.type = type
        self.sender = sender
        self.receiver = receiver
        self.amount_eth = amount_eth
        self.date = date
        self.__doc_ref__ = doc_ref
        if self.__doc_ref__:
            try:
                doc = doc_ref.get()
                if doc.exists:
                    data = doc.to_dict()
                    self.hash = data[u'hash']
                    self.type = data[u'type']
                    self.sender = data[u'sender']
                    self.receiver = data[u'receiver']
                    self.amount_eth = data[u'amount_eth']
                    self.date = data[u'date']
            except Exception as e:
                raise Exception("document does not exists! Error type {}".format(type(e)))

    @property
    # would rise an exception if document is not yet created
    def id(self):
        return self.__doc_ref__.id if self.__doc_ref__ else None

    @property
    # would rise an exception if document is not yet created
    def parent(self):
        return self.__coll_ref__.id if self.__coll_ref__ else None

    @property
    def exists(self):
        return self.__doc_ref__.get().exists if self.__doc_ref__ else False

    # Create new document -- private method
    def __create(self):
        if self.__doc_ref__ is None:
            self.__doc_ref__ = self.__coll_ref__.document()
            my_json = self.json()
            self.__doc_ref__.set(my_json[self.id])
            return my_json
        return self.json()

    def json(self):
        return {
            u'{}'.format(self.id): {
                u'id': u'{}'.format(str(self.id)),
                u'hash': u'{}'.format(str(self.hash)),
                u'type': u'{}'.format(str(self.type)),
                u'sender': u'{}'.format(str(self.sender)),
                u'receiver': u'{}'.format(str(self.receiver)),
                u'amount_eth': u'{}'.format(str(self.amount_eth)),
                u'date': u'{}'.format(str(self.date))
            }
        }

    def save_to_db(self):
        '''
        Create new transaction
        :return: json of new created transaction
        '''
        return self.__create()

    def delete_from_db(self):
        '''
        if a transaction exists then delete otherwise we don't want to let the user delete a non existing transaction
        :return: void
        '''
        if self.exists:
            self.__doc_ref__.delete()
            self.__doc_ref__ = None

    @classmethod
    def get_all(cls):
        docs = cls.__coll_ref__.stream()
        ret = dict()
        for doc in docs:
            ret[doc.id] = doc.to_dict()
        return ret

    @classmethod
    def find_by_id(cls, id):
        doc_ref = cls.__coll_ref__.document(u'{}'.format(id))
        return TransactionModel(doc_ref=doc_ref)
    
    @classmethod
    def delete_by_id(cls, id):
        bet = TransactionModel.find_by_id(id)
        if bet.exists:
            bet.delete_from_db()

    @classmethod
    def find_by_sender(cls, sender):
        docs = cls.__coll_ref__.where('sender', '==', sender).stream()
        ret = dict()
        for doc in docs:
            ret[doc.id] = doc.to_dict()
        return ret