from google.cloud import firestore

from db import db


class UserModel:
    __coll_ref__ = db.collection(u'{}'.format('users'))
    __doc_ref__ = None

    def __init__(self, address, themes = None,doc_ref=None):
        self.address = address
        self.themes = themes
        if (not themes):
            self.themes = list()
        self.__doc_ref__ = doc_ref
        if self.__doc_ref__:
            try:
                doc = doc_ref.get()
                if doc.exists:
                    data = doc.to_dict()
                    self.address = data[u'address']
                    self.themes = data[u'themes']
            except Exception as e:
                raise Exception("document does not exists! Error type {}".format(type(e)))

    @property
    # would rise an exception if document is not yet created
    def id(self):
        return self.__doc_ref__.id if self.__doc_ref__ else None

    @property
    # would rise an exception if document is not yet created
    def parent(self):
        return self.__coll_ref__.id if self.__coll_ref__ else None

    @property
    def exists(self):
        return self.__doc_ref__.get().exists if self.__doc_ref__ else False

    # Create new document -- private method
    def __create(self):
        if self.__doc_ref__ is None:
            self.__doc_ref__ = self.__coll_ref__.document()
            my_json = self.json()
            self.__doc_ref__.set(my_json[self.id])
            return my_json
        return self.json()

    def json(self):
        return {
            u'{}'.format(self.id): {
                u'id': u'{}'.format(str(self.id)),
                u'address': u'{}'.format(str(self.address)),
                u'themes': self.themes
            }
        }

    def save_to_db(self):
        '''
        Create new user
        :return: json of new created user
        '''
        return self.__create()

    def delete_from_db(self):
        '''
        if a user exists then delete otherwise we don't want to let the user delete a non existing user
        :return: void
        '''
        if self.exists:
            self.__doc_ref__.delete()
            self.__doc_ref__ = None

    def update_from_db(self, address=None, themes = None):
        # if it's already created then update
        if self.exists:
            if address:
                self.address = address
                self.__doc_ref__.update({u'address': u'{}'.format(address)})
            if themes:
                self.themes = themes
                self.__doc_ref__.update({u'themes': u'{}'.format(themes)})

    @classmethod
    def get_all(cls):
        docs = cls.__coll_ref__.stream()
        ret = dict()
        for doc in docs:
            ret[doc.id] = doc.to_dict()
        return ret

    @classmethod
    def find_by_id(cls, id):
        doc_ref = cls.__coll_ref__.document(u'{}'.format(id))
        return UserModel(doc_ref=doc_ref)

    @classmethod
    def delete_by_id(cls, id):
        user = UserModel.find_by_id(id)
        if user.exists:
            user.delete_from_db()


    @classmethod
    def find_by_address(cls, address):
        docs = cls.__coll_ref__.where('address', '==', address).stream()
        ret = dict()
        for doc in docs:
            ret[doc.id] = doc.to_dict()
        return ret

    @classmethod
    def add_theme_to_user(cls, id, theme_id):
        try:
            doc = cls.__coll_ref__.document(id)
            if doc.get().exists:
                docdict = doc.get().to_dict()
                if theme_id in docdict['themes']:
                    raise Exception("The user has already this theme.")
                else:
                    doc.update({u'themes': firestore.ArrayUnion([theme_id])})
            else:
                raise Exception("Document does not exists!")
        except Exception as e:
            raise Exception(e)

    @classmethod
    def delete_theme_from_user(cls, id, theme_id):
        try:
            doc = cls.__coll_ref__.document(id)
            if doc.get().exists:
                docdict = doc.get().to_dict()
                if theme_id in docdict['themes']:
                    doc.update({u'themes': firestore.ArrayRemove([theme_id])})
                else:
                    raise Exception("The user has not have this theme.")
            else:
                raise Exception("Document does not exists!")
        except Exception as e:
            raise Exception(e)