
import json
from google.cloud import firestore

from db import db


class WordleModelSpanish:
    __coll_ref__ = db.collection(u'{}'.format('wordle-spanish'))
    __doc_ref__ = None

    def __init__(self, user = None, hashPayment = None, hashReward = None, win = None, played = None, doc_ref=None):
        self.user = user
        self.hashPayment = hashPayment
        self.hashReward = hashReward
        self.win = win
        self.played = played
        self.__doc_ref__ = doc_ref
        if self.__doc_ref__:
            try:
                doc = doc_ref.get()
                if doc.exists:
                    data = doc.to_dict()
                    self.user = data[u'user']
                    self.hashPayment = data[u'hashPayment']
                    self.hashReward = data[u'hashReward']
                    self.win = data[u'win']
                    self.played = data[u'played']
            except Exception as e:
                raise Exception("document does not exists! Error type {}".format(type(e)))

    @property
    # would rise an exception if document is not yet created
    def id(self):
        return self.__doc_ref__.id if self.__doc_ref__ else None

    @property
    # would rise an exception if document is not yet created
    def parent(self):
        return self.__coll_ref__.id if self.__coll_ref__ else None

    @property
    def exists(self):
        return self.__doc_ref__.get().exists if self.__doc_ref__ else False

    # Create new document -- private method
    def __create(self):
        if self.__doc_ref__ is None:
            self.__doc_ref__ = self.__coll_ref__.document()
            my_json = self.json()
            self.__doc_ref__.set(my_json[self.id])
            return my_json
        return self.json()

    def json(self):
        return {
            u'{}'.format(self.id): {
                u'id': u'{}'.format(str(self.id)),
                u'user': u'{}'.format(str(self.user)),
                u'hashPayment': u'{}'.format(str(self.hashPayment)),
                u'hashReward': u'{}'.format(str(self.hashReward)),
                u'win': u'{}'.format(str(self.win)),
                u'played': u'{}'.format(str(self.played)),
            }
        }

    def save_to_db(self):
        '''
        Create new wordle spanish
        :return: json of new created wordle spanish
        '''
        return self.__create()

    def delete_from_db(self):
        '''
        if a wordle spanish exists then delete otherwise we don't want to let the user delete a non existing wordle spanish
        :return: void
        '''
        if self.exists:
            self.__doc_ref__.delete()
            self.__doc_ref__ = None

    def update_from_db(self, hashPayment = None, hashReward = None, win = None, played = None):
        # if it's already created then update
        if self.exists:
            if hashPayment:
                self.hashPayment = hashPayment
                self.__doc_ref__.update({u'hashPayment': u'{}'.format(hashPayment)})
            if hashReward:
                self.hashReward = hashReward
                self.__doc_ref__.update({u'hashReward': u'{}'.format(hashReward)})
            if win:
                self.win = win
                self.__doc_ref__.update({u'win': u'{}'.format(win)})
            if played:
                self.played = played
                self.__doc_ref__.update({u'played': u'{}'.format(played)})

    @classmethod
    def get_all(cls):
        docs = cls.__coll_ref__.stream()
        ret = dict()
        for doc in docs:
            ret[doc.id] = doc.to_dict()
        return ret
    
    @classmethod
    def delete_all(cls):
        docs = cls.__coll_ref__.stream()
        for doc in docs:
            WordleModelSpanish.find_by_id(doc.id).delete_from_db()

    @classmethod
    def find_by_id(cls, id):
        doc_ref = cls.__coll_ref__.document(u'{}'.format(id))
        return WordleModelSpanish(doc_ref=doc_ref)

    @classmethod
    def update_by_address(cls, address, hashPayment = None, hashReward = None, win = None, played = None):
        wordle_spanish = WordleModelSpanish.find_by_id(WordleModelSpanish.get_id_by_user(address))
        if wordle_spanish.exists:
            wordle_spanish.update_from_db(hashPayment = hashPayment, hashReward = hashReward, win = win, played = played)
            return wordle_spanish
    
    @classmethod
    def delete_by_id(cls, id):
        wordle_spanish = WordleModelSpanish.find_by_id(id)
        if wordle_spanish.exists:
            wordle_spanish.delete_from_db()

    @classmethod
    def find_by_user(cls, user):
        docs = cls.__coll_ref__.where('user', '==', user).stream()
        ret = dict()
        for doc in docs:
            ret[doc.id] = doc.to_dict()
        return ret
    
    @classmethod
    def get_id_by_user(cls, user):
        docs = cls.__coll_ref__.where('user', '==', user).stream()
        ret = dict()
        for doc in docs:
            return doc.id
        return ret
