from google.cloud import firestore

from db import db


class WordleWordModel:
    __coll_ref__ = db.collection(u'{}'.format('wordle-word'))
    __doc_ref__ = None

    def __init__(self, word= None, language= None, valid_date= None, update_date= None, doc_ref=None):
        self.word = word
        self.language = language
        self.valid_date = valid_date
        self.update_date = update_date
        self.__doc_ref__ = doc_ref
        if self.__doc_ref__:
            try:
                doc = doc_ref.get()
                if doc.exists:
                    data = doc.to_dict()
                    self.word = data[u'word']
                    self.language = data[u'language']
                    self.valid_date = data[u'valid_date']
                    self.update_date = data[u'update_date']
            except Exception as e:
                raise Exception("document does not exists! Error type {}".format(type(e)))

    @property
    # would rise an exception if document is not yet created
    def id(self):
        return self.__doc_ref__.id if self.__doc_ref__ else None

    @property
    # would rise an exception if document is not yet created
    def parent(self):
        return self.__coll_ref__.id if self.__coll_ref__ else None

    @property
    def exists(self):
        return self.__doc_ref__.get().exists if self.__doc_ref__ else False

    # Create new document -- private method
    def __create(self):
        if self.__doc_ref__ is None:
            self.__doc_ref__ = self.__coll_ref__.document()
            my_json = self.json()
            self.__doc_ref__.set(my_json[self.id])
            return my_json
        return self.json()

    def json(self):
        return {
            u'{}'.format(self.id): {
                u'id': u'{}'.format(str(self.id)),
                u'word': u'{}'.format(str(self.word)),
                u'language': u'{}'.format(str(self.language)),
                u'valid_date': u'{}'.format(str(self.valid_date)),
                u'update_date': u'{}'.format(str(self.update_date))
            }
        }

    def save_to_db(self):
        '''
        Create new word
        :return: json of new created word
        '''
        return self.__create()

    def delete_from_db(self):
        '''
        if a word exists then delete otherwise we don't want to let the user delete a non existing word
        :return: void
        '''
        if self.exists:
            self.__doc_ref__.delete()
            self.__doc_ref__ = None

    def update_from_db(self, word=None, valid_date=None, update_date=None):
        # if it's already created then update
        if self.exists:
            if word:
                self.word = word
                self.__doc_ref__.update({u'word': u'{}'.format(word)})
            if valid_date:
                self.valid_date = valid_date
                self.__doc_ref__.update({u'valid_date': u'{}'.format(valid_date)})
            if update_date:
                self.update_date = update_date
                self.__doc_ref__.update({u'update_date': u'{}'.format(update_date)})

    @classmethod
    def get_all(cls):
        docs = cls.__coll_ref__.stream()
        ret = dict()
        for doc in docs:
            ret[doc.id] = doc.to_dict()
        return ret

    @classmethod
    def find_by_id(cls, id):
        doc_ref = cls.__coll_ref__.document(u'{}'.format(id))
        return WordleWordModel(doc_ref=doc_ref)

    @classmethod
    def update_by_id(cls, id, word, valid_date, update_date):
        wordle_word = WordleWordModel.find_by_id(id)
        if wordle_word.exists:
            wordle_word.update_from_db(word=word, valid_date=valid_date, update_date=update_date)
            return wordle_word
    
    @classmethod
    def delete_by_id(cls, id):
        word = WordleWordModel.find_by_id(id)
        if word.exists:
            word.delete_from_db()

    @classmethod
    def find_by_language(cls, language):
        docs = cls.__coll_ref__.where('language', '==', language).stream()
        ret = dict()
        for doc in docs:
            ret[doc.id] = doc.to_dict()
        return ret