from flask_restful import Resource, reqparse

from models.betModel import BetModel
from lock import lock
from datetime import datetime
from datetime import timedelta

from .auth import auth

class Bet(Resource):

    def get(self, bet_date=None):
        with lock.lock:
            try:
                if not bet_date:
                    bet_date = datetime.now().strftime('%d/%m/%y')
                else:
                    bet_date = (datetime.now() + timedelta(days=1)).strftime('%d/%m/%y')
                if bet_date:
                    print(bet_date)
                    bet = BetModel.find_by_date(bet_date)
                    print(bet)
                    if len(bet) > 0:
                        try:
                            return {'bet': bet}, 200
                        except Exception as e:
                            return {'message': 'An error ocurred while finding the content of the bet. '
                                               'Error {}:{}'.format(type(e), e)}, 404
                    else:
                        return {'message': 'This date is not available.'}, 404
                return {'message': 'No bet date was provided!'}, 400
            except Exception as e:
                return {'message': 'Internal server error. Error {}:{}'.format(type(e), e)}, 500

    @auth.login_required
    def post(self, bet_date=None):
        with lock.lock:
            parser = reqparse.RequestParser()

            parser.add_argument('amount_eth', type=str, required=True, help="This field cannot be left blank.")
            # parser.add_argument('users', type=str, required=True, help="This field cannot be left blank.")
            
            if not bet_date: 
                bet_date = datetime.now().strftime('%d/%m/%y')
            else: 
                bet_date = (datetime.now() + timedelta(days=1)).strftime('%d/%m/%y')

            data = parser.parse_args()
            if data:
                # bet_date = datetime.now().strftime('%d/%m/%y')
                amount_eth = data['amount_eth']
                # users = data['users']
                try:
                    print(bet_date +" " + amount_eth)
                    bet = BetModel(bet_date=bet_date, amount_eth=amount_eth)
                    my_json = bet.save_to_db()
                    return {'bet': my_json}, 201
                except Exception as e:
                    return {'message': 'Internal server error. Error {}:{}'.format(type(e), e)}, 500
            return

    @auth.login_required
    def delete(self, id):
        with lock.lock:
            try:
                BetModel.delete_by_id(id)
                return {'message': 'Bed deleted successfully'}, 200
            except Exception as e:
                return {'message': 'Internal server error. Error {}:{}'.format(type(e), e)}, 500

    @auth.login_required
    def put(self, bet_date=None):
        with lock.lock:
            parser = reqparse.RequestParser()
            try:
                parser.add_argument('bet_date', type=str)
            except:
                pass
            try:
                parser.add_argument('amount_eth', type=str)
            except:
                pass
            try:
                parser.add_argument('user', type=str)
            except:
                pass
            try:
                parser.add_argument('current_total_eth', type=str)
            except:
                pass

            data = parser.parse_args()

            current_total_eth = None

            if data['bet_date']: bet_date = data['bet_date']
            if data['amount_eth']: amount_eth = data['amount_eth']
            if data['user']: user = data['user']
            if data['current_total_eth']: current_total_eth = data['current_total_eth']
            
            
            if not current_total_eth:
                if user:
                    print(user)
                    # bet_date = datetime.now().strftime('%d/%m/%y')
                    if not bet_date: 
                        bet_date = datetime.now().strftime('%d/%m/%y')
                    else: 
                        bet_date = (datetime.now() + timedelta(days=1)).strftime('%d/%m/%y')
                    print(bet_date)
                    bet = BetModel.find_by_date(bet_date=bet_date)
                    bet_id= list(bet.keys())[0]
                    print(bet)
                    print(bet_id)
                    try:
                        BetModel.add_user_to_bet(id=bet_id, address= user)
                        bet = BetModel.find_by_date(bet_date=bet_date)
                        return {'bet': bet}, 200
                    except:
                        return {'message': 'Internal server error'}, 500
                else:
                    return {'message': 'Without a bet date and an user address, its not possible to save/modify a bet'}, 400
            else: 
                if not bet_date: 
                    bet_date = datetime.now().strftime('%d/%m/%y')
                else: 
                    bet_date = (datetime.now() + timedelta(days=1)).strftime('%d/%m/%y')
                try: 
                    bet = BetModel.find_by_date(bet_date=bet_date)
                    bet_id= list(bet.keys())[0]
                    #print(bet)
                    #print(bet_id)
                    current_eth = bet[bet_id]['current_total_eth']
                    print(current_eth)
                    print(type(current_eth))
                    print(float(current_total_eth))
                    print(type(current_total_eth))
                    current_total_eth = float(current_eth) - float(current_total_eth)
                    print(current_total_eth)
                    if (current_total_eth < float(0)): current_total_eth =float(0)
                    print(current_total_eth)
                    bet = BetModel.update_by_id(id = bet_id, current_total_eth=current_total_eth).json()
                    print(int(bet[bet_id]['current_total_eth']))
                    return {'bet': bet}, 200
                except:
                    return {'message': 'Internal server error'}, 500
    

class BetsList(Resource):

    def get(self):
        with lock.lock:
            try:
                response_code = 201
                ret = BetModel.get_all()
                if not ret:
                    response_code = 204
                return {'bets': ret}, response_code
            except:
                return {'message': 'Collection of bets not found'}, 400