from flask_restful import Resource, reqparse
import requests

from models.roomModel import RoomModel
from lock import lock
from datetime import datetime
from datetime import timedelta
import random
from .words import languages_available, words_spanish
from .encryption import encrypt

from .auth import auth

class Room(Resource):

    @auth.login_required
    def get(self, id=None):
        with lock.lock:
            try:
                if id:
                    print(id)
                    room = RoomModel.find_by_id(id)
                    print(room)
                    if room.exists:
                        try:
                            return {'room': room.json()}, 200
                        except Exception as e:
                            return {'message': 'An error ocurred while finding the content of the room. '
                                               'Error {}:{}'.format(type(e), e)}, 404
                    else:
                        return {'message': 'This room is not available.'}, 404
                return {'message': 'No address was provided!'}, 400
            except Exception as e:
                return {'message': 'Internal server error. Error {}:{}'.format(type(e), e)}, 500

    @auth.login_required
    def post(self, id=None):
        with lock.lock:
            parser = reqparse.RequestParser()

            parser.add_argument('amount_eth', type=str, required=True, help="This field cannot be left blank.")
            parser.add_argument('host', type=str, required=True, help="This field cannot be left blank.")     
            
            result = '-1'
            word = ''
            # mentres no sigui una paraula que estigui al diccionari
            while (not result != '-1'):
                word = random.choice(words_spanish)
                print(word) 
                # mirem si la paraula hi és al diccionari online
                url = 'https://es.wiktionary.org/w/api.php?action=query&titles='+word.lower()+'&format=json'
                resp = requests.get(url)
                result = list(resp.json()['query']['pages'].keys())[0]
            
            # encrypt the word
            word_encrypted = encrypt(word)
            word = word_encrypted.decode("utf-8", "ignore")
            print(word)

            data = parser.parse_args()
            if data:
                # bet_date = datetime.now().strftime('%d/%m/%y')
                amount_eth = data['amount_eth']
                host = data['host']
                # users = data['users']
                try:
                    print(word +" " + amount_eth)
                    room = RoomModel(word=word, amount_eth=amount_eth, host=host)
                    my_json = room.save_to_db()
                    print(room.id)
                    RoomModel.add_user_to_room(room.id, host)
                    room = RoomModel.find_by_id(id=room.id)
                    return {'room': room.json()}, 201
                except Exception as e:
                    return {'message': 'Internal server error. Error {}:{}'.format(type(e), e)}, 500
            return

    @auth.login_required
    def delete(self, id):
        with lock.lock:
            try:
                RoomModel.delete_by_id(id)
                return {'message': 'Room deleted successfully'}, 200
            except Exception as e:
                return {'message': 'Internal server error. Error {}:{}'.format(type(e), e)}, 500

    @auth.login_required
    def put(self, word=None):
        with lock.lock:
            parser = reqparse.RequestParser()
            try:
                parser.add_argument('id', type=str)
            except:
                pass
            try:
                parser.add_argument('user', type=str)
            except:
                pass
            try:
                parser.add_argument('current_total_eth', type=str)
            except:
                pass
            try:
                parser.add_argument('played', type=str)
            except:
                pass
            try:
                parser.add_argument('started', type=str)
            except:
                pass

            data = parser.parse_args()

            current_total_eth = None
            started = None
            played = None

            if data['id']: id = data['id']
            if data['played']: played = data['played']
            if data['user']: user = data['user']
            if data['current_total_eth']: current_total_eth = data['current_total_eth']
            if data['started']: started = data['started']

            if started:
                try:
                    print(type(bool(started)))
                    RoomModel.update_by_id(id=id, started=bool(started))
                    room = RoomModel.find_by_id(id=id)
                    return {'room': room.json()}, 200
                except:
                    return {'message': 'Internal server error'}, 500
            
            if not played:
                if not current_total_eth:
                    if user:
                        try:
                            print(user)
                            print(id)
                            RoomModel.add_user_to_room(id, user)
                            room = RoomModel.find_by_id(id=id)
                            return {'room': room.json()}, 200
                        except:
                            return {'message': 'Internal server error'}, 500
                    else:
                        return {'message': 'Without an user address, its not possible to save/modify a room'}, 400
                else: 
                    try: 
                        room = RoomModel.find_by_id(id=id).json()
                        room_id= list(room.keys())[0]
                        #print(bet)
                        #print(bet_id)
                        current_eth = room[room_id]['current_total_eth']
                        print(current_eth)
                        print(type(current_eth))
                        print(float(current_total_eth))
                        print(type(current_total_eth))
                        current_total_eth = float(current_eth) - float(current_total_eth)
                        print(current_total_eth)
                        if (current_total_eth < float(0)): current_total_eth =float(0)
                        print(current_total_eth)
                        room = RoomModel.update_by_id(id = room_id, current_total_eth=current_total_eth).json()
                        print(int(room[room_id]['current_total_eth']))
                        return {'room': room}, 200
                    except:
                        return {'message': 'Internal server error'}, 500
            else: # if played = True -> set user as played in the room
                #print("a")
                if user:
                    try:
                        print(user)
                        print(word)
                        room = RoomModel.find_by_id(id=id).json()
                        room_id= list(room.keys())[0]
                        print(room)
                        print(room_id)
                        RoomModel.set_user_played_from_room(id=room_id, address=user)
                        room = RoomModel.find_by_id(id=id)
                        return {'room': room.json()}, 200
                    except:
                        return {'message': 'Internal server error'}, 500
                else:
                    return {'message': 'Without an user address, its not possible to save/modify a room'}, 400
    

class RoomsList(Resource):

    @auth.login_required
    def get(self):
        with lock.lock:
            try:
                response_code = 201
                ret = RoomModel.get_all()
                if not ret:
                    response_code = 204
                return {'rooms': ret}, response_code
            except:
                return {'message': 'Collection of rooms not found'}, 400