from flask_restful import Resource, reqparse

from models.transactionModel import TransactionModel
from lock import lock
from datetime import datetime

from .auth import auth

class Transaction(Resource):

    def get(self, sender=None):
        with lock.lock:
            try:
                if sender:
                    transaction = TransactionModel.find_by_sender(sender=sender)
                    print(transaction)
                    if len(transaction) > 0:
                        try:
                            return {'transaction': transaction}, 200
                        except Exception as e:
                            return {'message': 'An error ocurred while finding the content of the transaction. '
                                               'Error {}:{}'.format(type(e), e)}, 404
                    else:
                        return {'message': 'This sender address is not available.'}, 404
                return {'message': 'No sender address was provided!'}, 400
            except Exception as e:
                return {'message': 'Internal server error. Error {}:{}'.format(type(e), e)}, 500

    @auth.login_required
    def post(self, sender=None):
        with lock.lock:
            parser = reqparse.RequestParser()

            parser.add_argument('hash', type=str, required=True, help="This field cannot be left blank.")
            parser.add_argument('type', type=str, required=True, help="This field cannot be left blank.")
            parser.add_argument('sender', type=str, required=True, help="This field cannot be left blank.")
            parser.add_argument('receiver', type=str, required=True, help="This field cannot be left blank.")
            parser.add_argument('amount_eth', type=str, required=True, help="This field cannot be left blank.")

            data = parser.parse_args()
            if data:
                hash = data['hash']
                type = data['type']
                sender = data['sender']
                receiver = data['receiver']
                amount_eth = data['amount_eth']
                date = datetime.now().strftime('%d/%m/%y %H:%M:%S')
                try:
                    transaction = TransactionModel(hash=hash, type=type, sender=sender, receiver=receiver, amount_eth=amount_eth, date=date)
                    my_json = transaction.save_to_db()
                    return {'transaction': my_json}, 201
                except Exception as e:
                    return {'message': 'Internal server error. Error {}:{}'.format(type(e), e)}, 500
            return

    @auth.login_required
    def delete(self, id):
        with lock.lock:
            try:
                TransactionModel.delete_by_id(id)
                return {'message': 'Transaction deleted successfully'}, 200
            except Exception as e:
                return {'message': 'Internal server error. Error {}:{}'.format(type(e), e)}, 500
    

class TransactionsList(Resource):

    def get(self):
        with lock.lock:
            try:
                response_code = 201
                ret = TransactionModel.get_all()
                if not ret:
                    response_code = 204
                return {'transactions': ret}, response_code
            except:
                return {'message': 'Collection of transactions not found'}, 400