from flask_restful import Resource, reqparse

from models.userModel import UserModel
from lock import lock
from resources.themes import Theme
from .auth import auth

class Users(Resource):

    def get(self, address=None):
        with lock.lock:
            try:
                if address:
                    user = UserModel.find_by_address(address)
                    print(user)
                    if len(user) > 0:
                        #my_json = user.json()
                        try:
                            return {'user': user}, 200
                        except Exception as e:
                            return {'message': 'An error ocurred while finding the content of user. '
                                               'Error {}:{}'.format(type(e), e)}, 404
                    return {'message': 'User does not exists'}, 404
                return {'message': 'No address was provided!'}, 400
            except Exception as e:
                return {'message': 'Internal server error. Error {}:{}'.format(type(e), e)}, 500

    @auth.login_required
    def post(self, address=None):
        with lock.lock:
            parser = reqparse.RequestParser()

            parser.add_argument('address', type=str, required=True, help="This field cannot be left blank.")
            parser.add_argument('themes', type=str, required=False)

            data = parser.parse_args()
            if data:
                address = data['address']
                themes = data['themes']
                try:
                    if not themes: 
                        themes = ['gPnd49raMVTkA76Cz5HY']
                    user = UserModel(address=address, themes=themes)
                    my_json = user.save_to_db()
                    return {'user': my_json}, 201
                except Exception as e:
                    return {'message': 'Internal server error. Error {}:{}'.format(type(e), e)}, 500
            return

    @auth.login_required
    def delete(self, id):
        with lock.lock:
            try:
                UserModel.delete_by_id(id)
                return {'message': 'User deleted successfully'}, 200
            except Exception as e:
                return {'message': 'Internal server error. Error {}:{}'.format(type(e), e)}, 500

    @auth.login_required
    def put(self):
        with lock.lock:
            parser = reqparse.RequestParser()

            try:
                parser.add_argument('address', type=str)
            except:
                pass
            try:
                parser.add_argument('theme', type=str)
            except:
                pass

            data = parser.parse_args()

            if data['address']: address = data['address']
            if data['theme']: theme = data['theme']
            if address:
                user = UserModel.find_by_address(address=address)
                user_id= list(user.keys())[0]
                #print(user_id)
                if theme:
                    UserModel.add_theme_to_user(id=user_id, theme_id=theme)
                    user = UserModel.find_by_address(address=address)
                try:
                    return {'user': user}, 200
                except:
                    return {'message': 'Internal server error'}, 500
            else:
                return {'message': 'Without an id and address, its not possible to save/modify an user'}, 400


class UserList(Resource):

    def get(self):
        with lock.lock:
            try:
                response_code = 201
                ret = UserModel.get_all()
                if not ret:
                    response_code = 204
                return {'users': ret}, response_code
            except:
                return {'message': 'Collection of users not found'}, 400