from flask_restful import Resource, reqparse

from lock import lock
from datetime import datetime
from datetime import timedelta

from models.wordleModelSpanish import WordleModelSpanish

from .auth import auth

class WordleSpanish(Resource):

    def get(self, address=None):
        with lock.lock:
            try:
                if address:
                    user_wordle_spanish = WordleModelSpanish.find_by_user(address)
                    print(user_wordle_spanish)
                    if len(user_wordle_spanish) > 0:
                        #my_json = user.json()
                        try:
                            return {'user': user_wordle_spanish}, 200
                        except Exception as e:
                            return {'message': 'An error ocurred while finding the content of user in Wordle Spanish. '
                                               'Error {}:{}'.format(type(e), e)}, 404
                    return {'message': 'User does not exists'}, 404
                return {'message': 'No address was provided!'}, 400
            except Exception as e:
                return {'message': 'Internal server error. Error {}:{}'.format(type(e), e)}, 500

    @auth.login_required
    def post(self, address=None):
        with lock.lock:
            parser = reqparse.RequestParser()

            parser.add_argument('user', type=str, required=True, help="This field cannot be left blank.")
            

            data = parser.parse_args()
            if data:
                user = data['user']
                try:
                    user_wordle_spanish = WordleModelSpanish(user=user, hashPayment="", hashReward="", win="", played="False")
                    my_json = user_wordle_spanish.save_to_db()
                    return {'user': my_json}, 201
                except Exception as e:
                    return {'message': 'Internal server error. Error {}:{}'.format(type(e), e)}, 500
            return

    @auth.login_required
    def delete(self, id):
        with lock.lock:
            try:
                WordleModelSpanish.delete_by_id(id)
                return {'message': 'User deleted successfully'}, 200
            except Exception as e:
                return {'message': 'Internal server error. Error {}:{}'.format(type(e), e)}, 500

    @auth.login_required
    def put(self, address = None):
        with lock.lock:
            parser = reqparse.RequestParser()
            
            try:
                parser.add_argument('user', type=str)
            except:
                pass
            try:
                parser.add_argument('hashPayment', type=str)
            except:
                pass
            try:
                parser.add_argument('hashReward', type=str)
            except:
                pass
            try:
                parser.add_argument('win', type=str)
            except:
                pass
            try:
                parser.add_argument('played', type=str)
            except:
                pass

            data = parser.parse_args()

            if data['user']: address = data['user']
            if data['hashPayment']: hash_payment = data['hashPayment']
            if data['hashReward']: hash_reward = data['hashReward']
            if data['win']: win = data['win']
            if data['played']: played = data['played']

            if not address:
                return {'message': 'Without an address, its not possible to save/modify an user in Wordle Spanish'}, 400
            else:
                try:
                    print("aaaa")
                    WordleModelSpanish.update_by_address(address=address, win=win, played=played)
                    return {'message': 'User in Wordle Spanish updated successfully'}, 200
                except:
                    return {'message': 'Internal server error'}, 500
    

class WordleSpanishList(Resource):

    def get(self):
        with lock.lock:
            try:
                response_code = 201
                ret = WordleModelSpanish.get_all()
                if not ret:
                    response_code = 204
                return {'Wordle Spanish': ret}, response_code
            except:
                return {'message': 'Collection of wordle spanish not found'}, 400