import { Button, ButtonBase } from "@mui/material";
import { InputBase, MenuItem, Select, styled } from "@material-ui/core";
import React from "react";
import '../how-to-play/htp-styles.css';

class About extends React.Component {
  state = {
    language: "english"
  }
  async componentDidMount() {
    const data = localStorage.getItem("stateHTP");
    if (data) {
      let parse = JSON.parse(data);
      console.log(parse.language)
      if (parse.language){
        await this.setState({
          language: parse.language,
        });
      }
    }
    //console.log(this.state)
  }
  async changeLanguage(language) {
    console.log(language)
    await this.setState({
      language: language,
    });
    await this.saveState();
    /*
    setTimeout(function () { 
      window.location.reload()
    }.bind(this), 1000);*/
  }
  saveState = () => {
    localStorage.setItem("stateHTP", JSON.stringify(this.state));
  };
  render() {
    var languages = ["spanish", "catalan", "english"]
    const BootstrapInput = styled(InputBase)(({ theme }) => ({
      'label + &': {
        marginTop: theme.spacing(3),
      },
      '& .MuiInputBase-input': {
        borderRadius: 4,
        position: 'relative',
        backgroundColor: theme.palette.background.paper,
        border: '1px solid #ced4da',
        fontSize: 16,
        padding: '10px 26px 10px 12px',
        transition: theme.transitions.create(['border-color', 'box-shadow']),
        // Use the system font instead of the default Roboto font.
        fontFamily: [
          '-apple-system',
          'BlinkMacSystemFont',
          '"Segoe UI"',
          'Roboto',
          '"Helvetica Neue"',
          'Arial',
          'sans-serif',
          '"Apple Color Emoji"',
          '"Segoe UI Emoji"',
          '"Segoe UI Symbol"',
        ].join(','),
        '&:focus': {
          borderRadius: 4,
          borderColor: '#80bdff',
          boxShadow: '0 0 0 0.2rem rgba(0,123,255,.25)',
        },
      },
    }));
    return (
      <div className="howtoplay">
        {this.state.language==="english"&&<div className="howtoplay-container">
          <h3 className="howtoplay-titulo">
            About Wordle Crypto
            <div className="howtoplay-right">
                <Select
                  labelId="demo-simple-select-label"
                  id="demo-simple-select"
                  value={this.state.language}
                  input={<BootstrapInput />}
                >
                  {Object.values(languages).map((language) => (
                    <MenuItem value={language} onClick={() => this.changeLanguage(language)}>{language}</MenuItem>
                  ))}
                </Select>
              </div>
          </h3>
          <p className="howtoplay-descripcion">
          <b>Wordle Crypto</b> is a <b>Web3</b> application, which means that it uses blockchain technology to perform economic transactions. 
          These transactions are performed on a TestNet, <b>Rinkeby</b>, which, unlike most well-known blockchains, this one uses 
          a "fake" Ethereum (like Monopoly money), commonly used by developers to develop Web3 applications and later 
          deploy them on a real blockchain. <b>MetaMask</b> has to be used as a wallet for cryptocurrencies (this "fake" 
          Ethereum) and will also be used as a Web3 <b>provider</b> and <b>signer</b> (to sign, confirm, each transaction). Wordle 
          Crypto also uses another provider to send the Ethereum to the client, called <b>Infura</b>.
          </p>

          <p className="howtoplay-descripcion">
          The <b>reward system</b> is common to both game modes. Before starting the game, a collection is made in which 
          all participants pay 0.001 ETH, i.e. the total collection is 0.001 ETH for the number of players of that Wordle. 
          The first player to guess the Wordle wins 70% of the total Ethereum collection, the next winner is rewarded with 
          70% of the remaining Ethereum and so recursively. In this way, more players are rewarded for playing Wordle 
          Crypto.
          </p>

          <p className="howtoplay-descripcion">
              Please feel free to answer this form in order to improve Wordle Crypto's features: 
          </p>

          <h3 className="howtoplay-btncontainer2">
              <button className="formbtn-howtoplay" onClick={() => window.open("https://forms.gle/E8CCN5no7U9GkA7a8")}>Feedback Form</button>
          </h3>


          <footer className="footer-howtoplay">
            <svg
              xmlns="http://www.w3.org/2000/svg"
              className="icon icon-tabler icon-tabler-brand-github"
              width="20"
              height="20"
              viewBox="0 0 24 24"
              strokeWidth="1.5"
              stroke="#a3a3a3"
              fill="none"
              strokeLinecap="round"
              strokeLinejoin="round"
            >
              <path stroke="none" d="M0 0h24v24H0z" fill="none" />
              <path d="M9 19c-4.3 1.4 -4.3 -2.5 -6 -3m12 5v-3.5c0 -1 .1 -1.4 -.5 -2c2.8 -.3 5.5 -1.4 5.5 -6a4.6 4.6 0 0 0 -1.3 -3.2a4.2 4.2 0 0 0 -.1 -3.2s-1.1 -.3 -3.5 1.3a12.3 12.3 0 0 0 -6.2 0c-2.4 -1.6 -3.5 -1.3 -3.5 -1.3a4.2 4.2 0 0 0 -.1 3.2a4.6 4.6 0 0 0 -1.3 3.2c0 4.6 2.7 5.7 5.5 6c-.6 .6 -.6 1.2 -.5 2v3.5" />
            </svg>
            <a href="https://github.com/jorbush">Jordi Bonet</a>
          </footer>
        </div>}
        {this.state.language==="catalan"&&<div className="howtoplay-container">
          
          <h3 className="howtoplay-titulo">
            SOBRE WORDLE CRYPTO
            <div className="howtoplay-right">
                <Select
                  labelId="demo-simple-select-label"
                  id="demo-simple-select"
                  value={this.state.language}
                  input={<BootstrapInput />}
                >
                  {Object.values(languages).map((language) => (
                    <MenuItem value={language} onClick={() => this.changeLanguage(language)}>{language}</MenuItem>
                  ))}
                </Select>
              </div>
          </h3>
          <p className="howtoplay-descripcion">
          <b>Wordle Crypto</b> és una aplicació <b>Web3</b>, el que significa que utilitza la tecnologia blockchain per realitzar transaccions econòmiques. Aquestes 
          transaccions es realitzen en una TestNet, <b>Rinkeby</b>, que, a diferència de la majoria de blockchains conegudes, aquesta utilitza un Ethereum 
          "fals" (com els diners del Monopoly), utilitzat habitualment pels desenvolupadors per desenvolupar aplicacions Web3 i posteriorment desplegar-les 
          en una blockchain real. <b>MetaMask</b> s'ha d'utilitzar com a cartera per a criptomonedes (aquest "fals" Ethereum) i també s'utilitzarà com a <b>proveïdor </b> 
          i <b>signant</b> Web3 (per signar, confirmar, cada transacció). Wordle Crypto també utilitza un altre proveïdor per enviar l'Ethereum al client, anomenat <b>Infura</b>.
          </p>
          
          <p className="howtoplay-descripcion">
          El <b>sistema de recompenses</b> és comú als dos modes de joc. Abans de començar el joc, es fa una recollida en la qual tots els participants 
          paguen 0,001 ETH, és a dir, la recaptació total és de 0,001 ETH pel nombre de jugadors d'aquest Wordle. El primer jugador que endevini 
          el Wordle guanya el 70% de la col·lecció total d'Ethereum, el següent guanyador es recompensa amb el 70% de l'Ethereum restant i, per tant, 
          de manera recursiva. D'aquesta manera, més jugadors són recompensats per jugar a Wordle Crypto.
          </p>


          <p className="howtoplay-descripcion">
          Si us plau, no dubteu a respondre aquest formulari per millorar les funcions de Wordle Crypto:
          </p>

          <h3 className="howtoplay-btncontainer2">
              <button className="formbtn-howtoplay" onClick={() => window.open("https://forms.gle/E8CCN5no7U9GkA7a8")}>Feedback Form</button>
          </h3>


          <footer className="footer-howtoplay">
            <svg
              xmlns="http://www.w3.org/2000/svg"
              className="icon icon-tabler icon-tabler-brand-github"
              width="20"
              height="20"
              viewBox="0 0 24 24"
              strokeWidth="1.5"
              stroke="#a3a3a3"
              fill="none"
              strokeLinecap="round"
              strokeLinejoin="round"
            >
              <path stroke="none" d="M0 0h24v24H0z" fill="none" />
              <path d="M9 19c-4.3 1.4 -4.3 -2.5 -6 -3m12 5v-3.5c0 -1 .1 -1.4 -.5 -2c2.8 -.3 5.5 -1.4 5.5 -6a4.6 4.6 0 0 0 -1.3 -3.2a4.2 4.2 0 0 0 -.1 -3.2s-1.1 -.3 -3.5 1.3a12.3 12.3 0 0 0 -6.2 0c-2.4 -1.6 -3.5 -1.3 -3.5 -1.3a4.2 4.2 0 0 0 -.1 3.2a4.6 4.6 0 0 0 -1.3 3.2c0 4.6 2.7 5.7 5.5 6c-.6 .6 -.6 1.2 -.5 2v3.5" />
            </svg>
            <a href="https://github.com/jorbush">Jordi Bonet</a>
          </footer>
        </div>}
        {this.state.language==="spanish"&&<div className="howtoplay-container">
          
          <h3 className="howtoplay-titulo">
            SOBRE WORDLE CRYPTO
            <div className="howtoplay-right">
                <Select
                  labelId="demo-simple-select-label"
                  id="demo-simple-select"
                  value={this.state.language}
                  input={<BootstrapInput />}
                >
                  {Object.values(languages).map((language) => (
                    <MenuItem value={language} onClick={() => this.changeLanguage(language)}>{language}</MenuItem>
                  ))}
                </Select>
              </div>
          </h3>
          <p className="howtoplay-descripcion">
          <b>Wordle Crypto</b> es una aplicación <b>Web3</b>, lo que significa que utiliza la tecnología blockchain para realizar transacciones económicas. 
          Estas transacciones se realizan en una TestNet, <b>Rinkeby</b>, que, a diferencia de las blockchains más conocidas, este utiliza un Ethereum 
          "falso" (como el dinero del Monopoly), comúnmente utilizado por los desarrolladores para desarrollar aplicaciones Web3 y 
          posteriormente desplegarlas en una blockchain real. Hay que utilizar <b>MetaMask</b> como cartera para las criptomonedas (este 
          falso Ethereum) y también se utilizará como <b>proveedor</b> y <b>firmante</b> de Web3 (para firmar, confirmar, cada transacción). Wordle 
          Crypto también utiliza otro proveedor para enviar el Ethereum al cliente, llamado <b>Infura</b>.
          </p>

          <p className="howtoplay-descripcion">
          El <b>sistema de recompensas</b> es común a ambas modalidades de juego. Antes de comenzar la partida, se realiza una recaudación en la que 
          todos los participantes pagan 0,001 ETH, es decir, la recaudación total es de 0,001 ETH por el número de jugadores de esa Wordle. 
          El primer jugador que adivine el Wordle gana el 70% de la recaudación total de Ethereum, el siguiente ganador es recompensado con el 
          70% del Ethereum restante y así recursivamente. De esta manera, más jugadores son recompensados por jugar a Wordle Crypto.
          </p>

          <p className="howtoplay-descripcion">
          Por favor, siéntase libre de responder a este formulario para mejorar las características de Wordle Crypto:
          </p>

          <h3 className="howtoplay-btncontainer2">
              <button className="formbtn-howtoplay" onClick={() => window.open("https://forms.gle/E8CCN5no7U9GkA7a8")}>Feedback Form</button>
          </h3>


          <footer className="footer-howtoplay">
            <svg
              xmlns="http://www.w3.org/2000/svg"
              className="icon icon-tabler icon-tabler-brand-github"
              width="20"
              height="20"
              viewBox="0 0 24 24"
              strokeWidth="1.5"
              stroke="#a3a3a3"
              fill="none"
              strokeLinecap="round"
              strokeLinejoin="round"
            >
              <path stroke="none" d="M0 0h24v24H0z" fill="none" />
              <path d="M9 19c-4.3 1.4 -4.3 -2.5 -6 -3m12 5v-3.5c0 -1 .1 -1.4 -.5 -2c2.8 -.3 5.5 -1.4 5.5 -6a4.6 4.6 0 0 0 -1.3 -3.2a4.2 4.2 0 0 0 -.1 -3.2s-1.1 -.3 -3.5 1.3a12.3 12.3 0 0 0 -6.2 0c-2.4 -1.6 -3.5 -1.3 -3.5 -1.3a4.2 4.2 0 0 0 -.1 3.2a4.6 4.6 0 0 0 -1.3 3.2c0 4.6 2.7 5.7 5.5 6c-.6 .6 -.6 1.2 -.5 2v3.5" />
            </svg>
            <a href="https://github.com/jorbush">Jordi Bonet</a>
          </footer>
        </div>}
      </div>
    );
  }
  }
  export default About;