import {AppBar,Toolbar,Typography,makeStyles,Button,IconButton,Drawer,Link,MenuItem,} from "@material-ui/core";
import MenuIcon from "@material-ui/icons/Menu";
import React, { useState, useEffect } from "react";
import { Link as RouterLink } from "react-router-dom";
import ConnectedTag from "../metamask-auth/connected";
import PropTypes from 'prop-types';
import { useNavigate } from "react-router-dom";
import { ToastContainer, toast } from 'react-toastify';
import Grid from '@material-ui/core/Grid';
import Address from "../metamask-auth/address";
import { checkIfWalletIsConnected } from "../metamask-auth/connect";
import { ethers } from "ethers";

  
const headersData = [
    {
      label: "How to play",
      href: "/how-to-play",
    },
    {
        label: "Wordle Crypto",
        href: "/wordle",
    },
    {
        label: "Multiplayer",
        href: "/multiplayer",
    },
    {
        label: "Send Ether",
        href: "/send-ethereum",
    },
    {
        label: "Themes Store",
        href: "/store",
    },
    {
        label: "Obtain Cryptos",
        href: "/obtain-cryptos",
    },
    {
      label: "About",
      href: "/about",
    },
    
];
  
const useStyles = makeStyles(() => ({
    header: {
        backgroundColor: "#0A1A29",
        paddingLeft: 0,
        "@media (max-width: 900px)": {
        paddingLeft: 0,
        },
    },
    logo: {
        fontFamily: "Work Sans, sans-serif",
        fontWeight: 600,
        color: "#FFFEFE",
        textAlign: "left",
    },
    menuButton: {
        fontFamily: "Open Sans, sans-serif",
        fontWeight: 700,
        size: "18px",
        marginLeft: "38px",
    },
    toolbar: {
        display: "flex",
        justifyContent: "space-between",
    },
    drawerContainer: {
        padding: "20px 30px",
    },
}));
  
function Header(props) {
    //const {userAddress} = props;
    const { header, logo, menuButton, toolbar, drawerContainer } = useStyles();
    const [state, setState] = useState({
      mobileView: false,
      drawerOpen: false,
    });
    const { mobileView, drawerOpen } = state;
    const navigate = useNavigate();

    const [userAddress, setUserAddress] = useState("");
    const [addressLoaded, setAddressLoaded] = useState(false)

    useEffect(() => {
      checkIfWalletIsConnected(setUserAddress);
      // checked when the page loads the first time
    }, []);

    useEffect(() => {
      if (userAddress!==""){
        try{
          console.log(userAddress)
          ethers.utils.getAddress(userAddress);
        } catch (err) {
          navigate("/");
        }
      }
    }, [userAddress]);

    useEffect(() => {
      console.log("Connected: " + window.ethereum.isConnected())
      if (!window.ethereum.isConnected()){
        setUserAddress("")
      }
    }, [window.ethereum.isConnected()]);

    const logout = () => {
        toast('Session closed successfully');
        window.setTimeout(() => {
            navigate("/");
        }, 1500)
    }
  
    useEffect(() => {
      const setResponsiveness = () => {
        return window.innerWidth < 750
          ? setState((prevState) => ({ ...prevState, mobileView: true }))
          : setState((prevState) => ({ ...prevState, mobileView: false }));
      };
  
      setResponsiveness();
  
      window.addEventListener("resize", () => setResponsiveness());
  
      return () => {
        window.removeEventListener("resize", () => setResponsiveness());
      };
    }, []);
  
    const displayDesktop = () => {
        const handleDrawerOpen = () =>
        setState((prevState) => ({ ...prevState, drawerOpen: true }));
      const handleDrawerClose = () =>
        setState((prevState) => ({ ...prevState, drawerOpen: false }));
  
      return (
        <Toolbar>
            <Grid container>
                <Grid item xs={4} > 
                    <IconButton
                        {...{
                        edge: "start",
                        color: "inherit",
                        "aria-label": "menu",
                        "aria-haspopup": "true",
                        onClick: handleDrawerOpen,
                        }}
                    >
                        <MenuIcon />
                    </IconButton>
  
                    <Drawer
                        {...{
                        anchor: "left",
                        open: drawerOpen,
                        onClose: handleDrawerClose,
                        }}
                    >
                        <div className={drawerContainer}>{getDrawerChoices()}</div>
                    </Drawer>
                </Grid>
                <Grid item xs={4} container spacing={0} direction="column" alignItems="center" justifyContent="center">
                    {wordleCryptoLogo}
                </Grid>
                <Grid item xs={4} container spacing={0} direction="column" alignItems="center" justifyContent="center">
                    <div>
                        Connected with <Address userAddress={userAddress} />
                    </div>
                </Grid>
            </Grid>
            
        </Toolbar>
      );
    };
  
    const displayMobile = () => {
      const handleDrawerOpen = () =>
        setState((prevState) => ({ ...prevState, drawerOpen: true }));
      const handleDrawerClose = () =>
        setState((prevState) => ({ ...prevState, drawerOpen: false }));
  
      return (
        <Toolbar>
            <Grid container>
                <Grid item xs={2} > 
                    <IconButton
                        {...{
                        edge: "start",
                        color: "inherit",
                        "aria-label": "menu",
                        "aria-haspopup": "true",
                        onClick: handleDrawerOpen,
                        }}
                    >
                        <MenuIcon />
                    </IconButton>
  
                    <Drawer
                        {...{
                        anchor: "left",
                        open: drawerOpen,
                        onClose: handleDrawerClose,
                        }}
                    >
                        <div className={drawerContainer}>{getDrawerChoices()}</div>
                    </Drawer>
                </Grid>
                <Grid item xs={6} container spacing={0} direction="column" alignItems="center" justifyContent="center">
                    {wordleCryptoLogo}
                </Grid>
                <Grid item xs={4} container spacing={0} direction="column" alignItems="center" justifyContent="center">
                    <Address userAddress={userAddress} />
                </Grid>
            </Grid>
            
        </Toolbar>
      );
    };
  
    const getDrawerChoices = () => {
      return headersData.map(({ label, href }) => {
        return (
          <Link
            {...{
              component: RouterLink,
              to: href,
              color: "inherit",
              style: { textDecoration: "none" },
              key: label,
            }}
          >
            <MenuItem>{label}</MenuItem>
          </Link>
        );
      });
    };
  
    const wordleCryptoLogo = (
      <Typography variant="h6" component="h1" className={logo} >
        Wordle Crypto
      </Typography>
    );
  
  
    return (
      <header>
        <AppBar className={header}>
          {mobileView ? displayMobile() : displayDesktop()}
        </AppBar>
      </header>
    );
}
/*
Header.propTypes = {
    userAddress: PropTypes.string.isRequired
};*/
export default Header;