import { Button, ButtonBase, Grid, ImageList, ImageListItem } from "@mui/material";
import { Card, InputBase, MenuItem, Select, styled } from "@material-ui/core";
import React from "react";
import './htp-styles.css';

class HelpHowToPlay extends React.Component {
  state = {
    language: "english"
  }
  async componentDidMount() {
    const data = localStorage.getItem("stateHTP");
    if (data) {
      let parse = JSON.parse(data);
      console.log(parse.language)
      if (parse.language){
        await this.setState({
          language: parse.language,
        });
      }
    }
    //console.log(this.state)
  }
  async changeLanguage(language) {
    console.log(language)
    await this.setState({
      language: language,
    });
    await this.saveState();
    /*
    setTimeout(function () { 
      window.location.reload()
    }.bind(this), 1000);*/
  }
  saveState = () => {
    localStorage.setItem("stateHTP", JSON.stringify(this.state));
  };
  render() {
    var languages = ["spanish", "catalan", "english"]
    const BootstrapInput = styled(InputBase)(({ theme }) => ({
      'label + &': {
        marginTop: theme.spacing(3),
      },
      '& .MuiInputBase-input': {
        borderRadius: 4,
        position: 'relative',
        backgroundColor: theme.palette.background.paper,
        border: '1px solid #ced4da',
        fontSize: 16,
        padding: '10px 26px 10px 12px',
        transition: theme.transitions.create(['border-color', 'box-shadow']),
        // Use the system font instead of the default Roboto font.
        fontFamily: [
          '-apple-system',
          'BlinkMacSystemFont',
          '"Segoe UI"',
          'Roboto',
          '"Helvetica Neue"',
          'Arial',
          'sans-serif',
          '"Apple Color Emoji"',
          '"Segoe UI Emoji"',
          '"Segoe UI Symbol"',
        ].join(','),
        '&:focus': {
          borderRadius: 4,
          borderColor: '#80bdff',
          boxShadow: '0 0 0 0.2rem rgba(0,123,255,.25)',
        },
      },
    }));
    return (
      <div className="howtoplay">
        {this.state.language==="english"&&<div className="howtoplay-container">
          <h3 className="howtoplay-titulo">
            HOW TO PLAY
            <div className="howtoplay-right">
                <Select
                  labelId="demo-simple-select-label"
                  id="demo-simple-select"
                  value={this.state.language}
                  input={<BootstrapInput />}
                >
                  {Object.values(languages).map((language) => (
                    <MenuItem value={language} onClick={() => this.changeLanguage(language)}>{language}</MenuItem>
                  ))}
                </Select>
              </div>
          </h3>

          <p className="howtoplay-descripcion">
          First, make sure that you have selected the <b>Rinkeby test network</b> in MetaMask.
          </p>
          <ImageList cols={2} gap={38} sx={{ marginBottom: 5 }}>
              <ImageListItem key={'gifDesktop.gif'} sx={{ width: '110%' }}>
                <img src={require('./src/prueba_1_2.gif')} alt="desktop" />
              </ImageListItem>
              <ImageListItem key={'gifMobile.gif'} sx={{ marginLeft: '5%',width: '90%' }}>
                <img  src={require('./src/gifMobile.gif')} alt="mobile" />
              </ImageListItem>
          </ImageList>

          <p className="howtoplay-descripcion">
          You can <b>get free cryptocurrencies</b>, Ethereum from Rinkeby, to start playing Wordle Crypto in the section <a href="./obtain-cryptos">Obtain Cryptos</a>. 
          You will receive 0.003 ETH (equivalent to 3 bets). 
          </p>

          <p className="howtoplay-descripcion">
          We have two game modes: Wordle Crypto and a Multiplayer mode. In both the word to guess is in spanish.
          </p>

          <p className="howtoplay-descripcion">
          In the main mode <a href="./home">Wordle Crypto</a> is based on the popular Wordle concept: there is a word of the day, the Wordle, 
          and the first to guess it gets a bigger reward than the rest. To play this game mode you need to bet on the 
          previous day and you can play the Wordle from the next day (at 00:00).
          </p>
          <p className="howtoplay-descripcion">
          The <a href="./multiplayer">Multiplayer</a> mode is designed so that you can enjoy playing Wordle with your friends anytime. In this mode you 
          can create a room (with the "Create Room" option), which generates a key that you can pass to other players so that 
          they can join this room (with the "Join Room" option). Once all users are ready in the room, the host can start the 
          game and everyone plays a common Wordle: players have to guess the same word and the first one who guesses it wins 
          a reward much higher than the rest.
          </p>

          <p className="howtoplay-descripcion">
          You can spend your Ethereum from Rinkeby to buy aesthetic <b>themes</b>, to customize your Wordle Crypto page, at <a href="./store">Themes Store</a>.
          </p>

          <p className="howtoplay-descripcion">
          In case you run out of ether, you can ask another user to send you ether using <a href="./send-ethereum">Send Ether</a>.
          </p>
          

          <footer className="footer-howtoplay">
            <svg
              xmlns="http://www.w3.org/2000/svg"
              className="icon icon-tabler icon-tabler-brand-github"
              width="20"
              height="20"
              viewBox="0 0 24 24"
              strokeWidth="1.5"
              stroke="#a3a3a3"
              fill="none"
              strokeLinecap="round"
              strokeLinejoin="round"
            >
              <path stroke="none" d="M0 0h24v24H0z" fill="none" />
              <path d="M9 19c-4.3 1.4 -4.3 -2.5 -6 -3m12 5v-3.5c0 -1 .1 -1.4 -.5 -2c2.8 -.3 5.5 -1.4 5.5 -6a4.6 4.6 0 0 0 -1.3 -3.2a4.2 4.2 0 0 0 -.1 -3.2s-1.1 -.3 -3.5 1.3a12.3 12.3 0 0 0 -6.2 0c-2.4 -1.6 -3.5 -1.3 -3.5 -1.3a4.2 4.2 0 0 0 -.1 3.2a4.6 4.6 0 0 0 -1.3 3.2c0 4.6 2.7 5.7 5.5 6c-.6 .6 -.6 1.2 -.5 2v3.5" />
            </svg>
            <a href="https://github.com/jorbush">Jordi Bonet</a>
          </footer>
        </div>}
        {this.state.language==="catalan"&&<div className="howtoplay-container">
          
          <h3 className="howtoplay-titulo">
            COM JUGAR
            <div className="howtoplay-right">
                <Select
                  labelId="demo-simple-select-label"
                  id="demo-simple-select"
                  value={this.state.language}
                  input={<BootstrapInput />}
                >
                  {Object.values(languages).map((language) => (
                    <MenuItem value={language} onClick={() => this.changeLanguage(language)}>{language}</MenuItem>
                  ))}
                </Select>
              </div>
          </h3>

          <p className="howtoplay-descripcion">
          Primer, assegureu-vos que heu seleccionat la <b>xarxa de prova de Rinkeby</b> a MetaMask.
          </p>
          <ImageList cols={2} gap={38} sx={{ marginBottom: 5 }}>
              <ImageListItem key={'gifDesktop.gif'} sx={{ width: '110%' }}>
                <img src={require('./src/prueba_1_2.gif')} alt="desktop" />
              </ImageListItem>
              <ImageListItem key={'gifMobile.gif'} sx={{ marginLeft: '5%',width: '90%' }}>
                <img  src={require('./src/gifMobile.gif')} alt="mobile" />
              </ImageListItem>
          </ImageList>

          <p className="howtoplay-descripcion">
          Podeu obtenir <b>criptomonedes gratuïtes</b>, Ethereum de Rinkeby, per començar a jugar a Wordle Crypto a la secció <a href="./obtain-cryptos">Obtain Cryptos</a>. 
          Rebràs 0,003 ETH (equivalent a 3 apostes).
          </p>
          
          <p className="howtoplay-descripcion">
          Tenim dos modes de joc: Wordle Crypto i un mode multijugador. En tots dos la paraula endevinar està en castellà.
          </p>

          <p className="howtoplay-descripcion">
          En el mode principal, <a href="./home">Wordle Crypto</a> es basa en el popular concepte Wordle: hi ha una paraula del dia, 
          el Wordle, i el primer que l'endevina obté una recompensa més gran que la resta. Per jugar a aquesta modalitat de 
          joc cal apostar el dia anterior i podràs jugar al Wordle a partir de l'endemà (a les 00:00).
          </p>
          <p className="howtoplay-descripcion">
          El mode <a href="./multiplayer">Multiplayer</a> està dissenyat perquè pugueu gaudir jugant a Wordle amb els vostres amics en qualsevol 
          moment. En aquesta modalitat pots crear una sala (amb l'opció "Create Room"), que genera una clau que pots passar a altres jugadors 
          perquè s'incorporin a aquesta sala (amb l'opció "Join Room"). Un cop tots els usuaris estiguin preparats a la sala, l'amfitrió 
          pot començar el joc i tothom juga a un Wordle comú: els jugadors han d'endevinar la mateixa paraula i el primer que l'endevini 
          guanya una recompensa molt superior a la resta.
          </p>

          <p className="howtoplay-descripcion">
          Podeu gastar el vostre Ethereum de Rinkeby per comprar <b>temes</b> estètics, per personalitzar la vostra pàgina Wordle Crypto, a la <a href="./store">Themes Store</a>.
          </p>

          <p className="howtoplay-descripcion">
          En cas que us quedeu sense ether, podeu demanar a un altre usuari que us enviï l'ether fent servir <a href="./send-ethereum">Send Ether</a>.
          </p>

          <footer className="footer-howtoplay">
            <svg
              xmlns="http://www.w3.org/2000/svg"
              className="icon icon-tabler icon-tabler-brand-github"
              width="20"
              height="20"
              viewBox="0 0 24 24"
              strokeWidth="1.5"
              stroke="#a3a3a3"
              fill="none"
              strokeLinecap="round"
              strokeLinejoin="round"
            >
              <path stroke="none" d="M0 0h24v24H0z" fill="none" />
              <path d="M9 19c-4.3 1.4 -4.3 -2.5 -6 -3m12 5v-3.5c0 -1 .1 -1.4 -.5 -2c2.8 -.3 5.5 -1.4 5.5 -6a4.6 4.6 0 0 0 -1.3 -3.2a4.2 4.2 0 0 0 -.1 -3.2s-1.1 -.3 -3.5 1.3a12.3 12.3 0 0 0 -6.2 0c-2.4 -1.6 -3.5 -1.3 -3.5 -1.3a4.2 4.2 0 0 0 -.1 3.2a4.6 4.6 0 0 0 -1.3 3.2c0 4.6 2.7 5.7 5.5 6c-.6 .6 -.6 1.2 -.5 2v3.5" />
            </svg>
            <a href="https://github.com/jorbush">Jordi Bonet</a>
          </footer>
        </div>}
        {this.state.language==="spanish"&&<div className="howtoplay-container">
          
          <h3 className="howtoplay-titulo">
            CÓMO JUGAR
            <div className="howtoplay-right">
                <Select
                  labelId="demo-simple-select-label"
                  id="demo-simple-select"
                  value={this.state.language}
                  input={<BootstrapInput />}
                >
                  {Object.values(languages).map((language) => (
                    <MenuItem value={language} onClick={() => this.changeLanguage(language)}>{language}</MenuItem>
                  ))}
                </Select>
              </div>
          </h3>

          <p className="howtoplay-descripcion">
          En primer lugar, asegúrese de que ha seleccionado la <b>red de prueba Rinkeby</b> en MetaMask.
          </p>
          <ImageList cols={2} gap={38} sx={{ marginBottom: 5 }}>
              <ImageListItem key={'gifDesktop.gif'} sx={{ width: '110%' }}>
                <img src={require('./src/prueba_1_2.gif')} alt="desktop" />
              </ImageListItem>
              <ImageListItem key={'gifMobile.gif'} sx={{ marginLeft: '5%',width: '90%' }}>
                <img  src={require('./src/gifMobile.gif')} alt="mobile" />
              </ImageListItem>
          </ImageList>

          <p className="howtoplay-descripcion">
          Puedes conseguir <b>criptomonedas gratis</b>, Ethereum de Rinkeby, para empezar a jugar a Wordle Crypto en la sección <a href="./obtain-cryptos">Obtain Cryptos</a>. 
          Recibirás 0.003 ETH (equivalente a 3 apuestas).
          </p>
          
          <p className="howtoplay-descripcion">
          Tenemos dos modos de juego: Wordle Crypto y un modo Multijugador. En ambos la palabra a adivinar está en español.
          </p>

          <p className="howtoplay-descripcion">
          En el modo principal <a href="./home">Wordle Crypto</a> se basa en el popular concepto de Wordle: hay una palabra del día, el Wordle, 
          y el primero en adivinarla obtiene una mayor recompensa que el resto. Para jugar a este modo de juego hay que apostar por el día anterior 
          y se puede jugar al Wordle del día siguiente (a las 00:00).
          </p>
          <p className="howtoplay-descripcion">
          El modo <a href="./multiplayer">Multiplayer</a> está diseñado para que puedas disfrutar jugando al Wordle con tus amigos en cualquier 
          momento. En este modo puedes crear una sala (con la opción "Create Room"), que genera una clave que puedes pasar a otros jugadores para 
          que se unan a esta sala (con la opción "Join Room"). Una vez que todos los usuarios están listos en la sala, el anfitrión puede 
          iniciar el juego y todos juegan a un Wordle común: los jugadores tienen que adivinar la misma palabra y el primero que la adivine gana 
          una recompensa muy superior a la del resto.
          </p>

          <p className="howtoplay-descripcion">
          Puedes gastar tus Ethereum de Rinkeby para comprar <b>temas</b> estéticos, para personalizar tu página de Wordle Crypto, en <a href="./store">Themes Store</a>.
          </p>

          <p className="howtoplay-descripcion">
          En el caso de que te quedes sin ether, puedes pedir a otro usuario que te envie ether usando <a href="./send-ethereum">Send Ether</a>.
          </p>

          <footer className="footer-howtoplay">
            <svg
              xmlns="http://www.w3.org/2000/svg"
              className="icon icon-tabler icon-tabler-brand-github"
              width="20"
              height="20"
              viewBox="0 0 24 24"
              strokeWidth="1.5"
              stroke="#a3a3a3"
              fill="none"
              strokeLinecap="round"
              strokeLinejoin="round"
            >
              <path stroke="none" d="M0 0h24v24H0z" fill="none" />
              <path d="M9 19c-4.3 1.4 -4.3 -2.5 -6 -3m12 5v-3.5c0 -1 .1 -1.4 -.5 -2c2.8 -.3 5.5 -1.4 5.5 -6a4.6 4.6 0 0 0 -1.3 -3.2a4.2 4.2 0 0 0 -.1 -3.2s-1.1 -.3 -3.5 1.3a12.3 12.3 0 0 0 -6.2 0c-2.4 -1.6 -3.5 -1.3 -3.5 -1.3a4.2 4.2 0 0 0 -.1 3.2a4.6 4.6 0 0 0 -1.3 3.2c0 4.6 2.7 5.7 5.5 6c-.6 .6 -.6 1.2 -.5 2v3.5" />
            </svg>
            <a href="https://github.com/jorbush">Jordi Bonet</a>
          </footer>
        </div>}
      </div>
    );
  }
  }
  export default HelpHowToPlay;