import React, { useEffect, useState } from "react";
import "./MetaMaskAuth.css";

import Connect, {checkIfWalletIsConnected} from "./connect";

import axios from 'axios';
import { HostPath, passwordAuthorized, userAuthorized } from "../../constants/constants";
import ConnectedTag from "./connected";

function getTimeLeft(timeout) {
  return Math.ceil((timeout._idleStart + timeout._idleTimeout - Date.now()) / 1000);
}



function MetaMaskAuth({ onAddressChanged }) {
  const [userAddress, setUserAddress] = useState("");
  const [addressExists, setAddressExists] = useState();

  useEffect(() => {
    checkIfWalletIsConnected(setUserAddress);
    // checked when the page loads the first time
  }, []);

  const getUserByAddress = async (address) => {
    const path = HostPath.path + 'user/address/' + address
    await axios.get(path)
        .then(res => {
            console.log(res.data)
            console.log(res.status);
            setAddressExists(true)
        }).catch((error) => {
            console.log(error.message)
            setAddressExists(false)
        });
  }

  const postUserAddress = async (address) => {
    const path = HostPath.path + 'user/address/' + address
    const parameters = {
      address: address
  };
    await axios.post(path, parameters, {
      auth: {
        username: userAuthorized,
        password: passwordAuthorized
      }
    })
        .then(res => {
            console.log(res.data)
            console.log(res.status);
            if (res.status === 201) { // respuesta server is ok
              console.log('¡Todo bien!')
            }else {
                console.log("¡Algo ha ocurrido!");
            }
        }).catch((error) => {
            console.log(error.message)
        });
  }

  useEffect(() => {
    if (userAddress != "" && userAddress != "undefined"){
      onAddressChanged(userAddress);
      console.log('Address change: ' + userAddress)
      // check if this address is already on the database
      getUserByAddress(userAddress)
    }
  }, [userAddress]);

  useEffect(() => {
    if (addressExists === false){ // if not, create new user on database
      console.log('User with address '+ userAddress + " doesn't exists on the database.")
      console.log(addressExists)
      postUserAddress(userAddress)
    } else if (addressExists === true){
      console.log('User with address '+ userAddress + ' already exists on the database.')
    }
    
  }, [addressExists]);


  return userAddress!=="undefined" && userAddress!=="" ? (
    <ConnectedTag userAddress={userAddress}/>
  ) : (
    <Connect setUserAddress={setUserAddress}/>
  );
}
export default MetaMaskAuth;