// check is a mobile device or a desktop browser
function isMobileDevice() {
    return 'ontouchstart' in window || 'onmsgesturechange' in window;
}
export {isMobileDevice}

async function connect(onConnected) { //called when the user clicks the “Connect to MetaMask” button
    /*
    When MetaMask is installed as a browser extension, it will insert 
    the ethereum object to the window object on every page. If the ethereum 
    object is absent, it means MetaMask is not installed 
    and we display “Get MetaMask!” alert.
    */
    if (!window.ethereum) {
      if (isMobileDevice()) {
        const dappUrl = "wordle-crypto-jorbush.herokuapp.com/"; 
        const metamaskAppDeepLink = "https://metamask.app.link/dapp/" + dappUrl;
        window.open(metamaskAppDeepLink)
        return;
      }
      alert("Get MetaMask!");
      return;
    }
    
    /*
    But if it is present, we use the eth_requestAccounts method of the MetaMask API to 
    request a connection to the user’s wallet. This will trigger a popup from MetaMask 
    asking the user to grant our application access to the user’s address. 
    */
    const accounts = await window.ethereum.request({
      method: "eth_requestAccounts",
    });
    // MetaMask API will return a list of all accounts that the user granted access to. 
    // We use the first available account accounts[0] and call the onConnected callback
    onConnected(accounts[0]);
}
export {connect}

async function checkIfWalletIsConnected(onConnected) {
    if (window.ethereum) { // Check if ethereum object is present.
        // we get all accounts that the user has already granted access to 
        //via the eth_accounts method of the MetaMask API
        const accounts = await window.ethereum.request({
            method: "eth_accounts",
         }); 
        // take the first available account and use it as the userAddress
        if (accounts.length > 0) {
            const account = accounts[0];
            onConnected(account);
            return;
        } else{
            onConnected("undefined");
            return;
        }
        if (isMobileDevice()) {
            await connect(onConnected);
        }
    }
}
export {checkIfWalletIsConnected}

function Connect({ setUserAddress }) {
    return (
        <button className="button" onClick={() => connect(setUserAddress)}>
            Connect to MetaMask
        </button>
    );
}
export default Connect;