import { useEffect, useState } from "react";
import { ethers } from "ethers";
import "animate.css/animate.min.css";
import "react-toastify/dist/ReactToastify.css";
import { ToastContainer, toast, cssTransition } from "react-toastify";
import { Card, CardActions, CardContent, Container, makeStyles } from "@material-ui/core";
import "../send-eth/styles.css";
import { EndpointInfuraRinkeby, HostPath, WordleEthereumAddress, WordleEthereumAddress2, WordleMetaMaskAccountPrivateKey, WordleMetaMaskAccountPrivateKey2 } from "../../constants/constants";
import axios from 'axios';
import { Transaction } from '@ethereumjs/tx'
import Common, { Chain } from '@ethereumjs/common'
import Web3 from "web3";
import { startPayment } from "../send-eth/SendETH";

const bounce = cssTransition({
    enter: "animate__animated animate__bounceIn",
    exit: "animate__animated animate__bounceOut"
});

const useStyles = makeStyles({
    card: {
      maxWidth: 345,
      boxShadow: "0 5px 8px 0 rgba(0, 0, 0, 0.3)",
      backgroundColor: "#fafafa",
    },
});

export default function CreateRoom() {
  const [error, setError] = useState();
  const [txs, setTxs] = useState([]);
  const classes = useStyles();
  useEffect(()=>{
    if (error !== undefined){
        console.log(error)
        toast.dark(error, {transition: bounce});
    }
  },[error])

  useEffect(()=>{
    if (txs.length > 0){
        console.log(txs)
        toast.dark("Successful transaction!", {transition: bounce});
    }
  },[txs])

  const handleSubmit = async (e) => {
    e.preventDefault();
    const data = new FormData(e.target);
    setError();
    await startPayment({
      setError,
      setTxs,
      ether: data.get("ether"),
      addr: data.get("addr")
    });
  };

  return (
      <Container>
      <ToastContainer className="toast" transition={bounce} />
        
    <div className='center'>
        <div className="form">
        <form onSubmit={handleSubmit}>
            <div className="title">
                Create Room
            </div>
            <div className="input-container ic1">
                <input
                    type="text"
                    name="addr"
                    className="input"
                    placeholder=" "
                />
                <div className="cut cut-long"></div>
                <label className="placeholder">Recipient Address</label>
                
            </div>
            <div className="input-container ic2">
                <input
                        name="ether"
                        type="text"
                        className="input"
                        placeholder=" "
                    />
                    <div className="cut cut-long-shorter"></div>
                    <label className="placeholder">Amount in ETH</label>
            </div>
            <button type="text" className="submit">SEND</button>
        </form>
        </div>
    </div>
    </Container>
  );
}
