import { useEffect, useState } from "react";
import { ethers } from "ethers";
import "animate.css/animate.min.css";
import "react-toastify/dist/ReactToastify.css";
import { ToastContainer, toast, cssTransition } from "react-toastify";
import { Card, CardActions, CardContent, Container, makeStyles } from "@material-ui/core";
import { HostPath, WordleEthereumAddress, AmountETHMultiplayer, addressWordleETH, userAuthorized, passwordAuthorized} from "../../constants/constants";
import "../send-eth/styles.css";
import axios from 'axios';
import { Transaction } from '@ethereumjs/tx'
import Common, { Chain } from '@ethereumjs/common'
import Web3 from "web3";
import { startPayment } from "../send-eth/SendETH";
import { Navigate, useLocation, useNavigate } from 'react-router-dom';
import { checkIfWalletIsConnected } from "../metamask-auth/connect";

const bounce = cssTransition({
    enter: "animate__animated animate__bounceIn",
    exit: "animate__animated animate__bounceOut"
});

const useStyles = makeStyles({
    card: {
      maxWidth: 345,
      boxShadow: "0 5px 8px 0 rgba(0, 0, 0, 0.3)",
      backgroundColor: "#fafafa",
    },
});

export default function JoinRoom() {
  const [error, setError] = useState();
  const [txs, setTxs] = useState([]);
  const classes = useStyles();
  const [loading, setLoading] = useState(false);
  const [roomID, setRoomID] = useState();
  const navigate = useNavigate();
  const [userInRoom, setUserInRoom] = useState();
  const [userAddress, setUserAddress] = useState("");
  const [loaded, setLoaded] = useState(false);
  const [roomExists, setRoomExists] = useState();
  const [roomAlreadyStarted, setRoomAlreadyStarted] = useState(true);

  const putUserInRoom = async () => {
    const path = HostPath.path + 'room'
    const parameters = {
        user: userAddress,
        id: roomID
    };
    console.log(parameters)
    await axios.put(path, parameters, {
      auth: {
        username: userAuthorized,
        password: passwordAuthorized
      }
    })
        .then(res => {
            console.log(res.data)
            console.log(res.status);
            if (res.status === 200) { // respuesta server is ok
                console.log('put user in room success')
                setTimeout(function () { 
                  setUserInRoom(true)
                }, 5000);
            }else {
                console.log("put user in room failed");
                setUserInRoom(false)
            }
        }).catch((error) => {
            console.log(error.message)
        });
  }

  const getIfRoomExists = async () => {
    const path = HostPath.path + 'room/id/' + roomID
    await axios.get(path, {
      auth: {
        username: userAuthorized,
        password: passwordAuthorized
      }
    })
        .then(res => {
            //console.log(res.data)
            console.log(res.status);
            if (res.status === 200){
              setRoomExists(true)
            }
        }).catch((error) => {
            console.log(error.message)
            setRoomExists(false)
        });
  } 

  const getIfUserInRoom = async () => {
    const path = HostPath.path + 'room/id/' + roomID
    await axios.get(path, {
      auth: {
        username: userAuthorized,
        password: passwordAuthorized
      }
    })
        .then(res => {
            //console.log(res.data)
            //console.log(res.status);
            let value = Object.values(res.data.room)
            let users = Object.keys(value.at(0).users)
            if (users.includes(userAddress)) {
              setUserInRoom(true)
              console.log("User is already in this room.")
            }else{
              setUserInRoom(false)
              console.log("User isn't already in this room.")
            }
        }).catch((error) => {
            console.log(error.message)
        });
  } 

  const getIfRoomStarted = async () => {
    const path = HostPath.path + 'room/id/' + roomID
    await axios.get(path, {
      auth: {
        username: userAuthorized,
        password: passwordAuthorized
      }
    })
        .then(res => {
          let value = Object.values(res.data.room)
          var start = value.at(0).started
          console.log(start)
          setRoomAlreadyStarted(start)
        }).catch((error) => {
            console.log(error.message)
        });
  } 

  useEffect(() => {
    checkIfWalletIsConnected(setUserAddress);
  }, []);

  useEffect(() => {
      if (userAddress!==""){
          try{
              console.log(userAddress)
              ethers.utils.getAddress(userAddress);
              setLoaded(true)
          } catch (err) {
              Navigate("/");
          }
      }
  }, [userAddress]);

  useEffect(()=>{
    if (error !== undefined){
        console.log(error)
        toast.dark(error, {transition: bounce});
    }
  },[error])

  useEffect(()=>{
      if (txs.length > 0){
          console.log(txs)
          toast.dark("Successful transaction!", {transition: bounce});
          setLoading(true)
          putUserInRoom()
      }
  },[txs])

  const handleSubmit = async (e) => {
    e.preventDefault();
    const data = new FormData(e.target);
    setError();
    var rID = data.get("roomID")
    setRoomID(rID)
  };

  useEffect(() => {
    if (loaded){
      console.log(roomID)
      if (roomID && roomID !== ""){
        // check if room id exists
        getIfRoomExists()
      } else{
        setError("You have to provide a room ID.")
      }
    }
  }, [roomID]);

  useEffect(() => {
    if (roomID && loaded){
      if (roomExists){
        // check if the room already started
        getIfRoomStarted()
        // check if user is already in the room -> if is the case can join free
        getIfUserInRoom()
      } else{
        setError("This room doesn't exist.")
      }
    }
  }, [roomExists]);

  useEffect(() => {
    if (loaded && roomID && roomExists){
        if (userInRoom){
          navigate("/wordle-multiplayer", {state:{roomID: roomID}}) // <- pass roomID created
        } else{
          if (!roomAlreadyStarted){
            startPayment({
              setError,
              setTxs,
              ether: AmountETHMultiplayer.toString(),
              addr: addressWordleETH
            });
          }else{
            setError("This room has already started.")
          }
        }
    }
  }, [userInRoom]);

  return (
      <Container>
      <ToastContainer className="toast" transition={bounce} />
        
    <div className='center'>
        <div className="form" style={{height: "300px"}}>
        <form onSubmit={handleSubmit}>
            <div className="title">
                Join Room
            </div>
            <div className="input-container ic2">
                <input
                        name="roomID"
                        type="text"
                        className="input"
                        placeholder=" "
                    />
                    <div className="cut cut-short"></div>
                    <label className="placeholder">Room ID</label>
            </div>
            <button type="text" className="submit" disabled={loading}>JOIN</button>
        </form>
        </div>
    </div>
    </Container>
  );
}
