import { Box } from "@material-ui/core";
import axios from "axios";
import React, { useEffect, useState } from "react";
import { Navigate, useNavigate } from "react-router-dom";
import { HostPath, passwordAuthorized, userAuthorized } from "../../constants/constants";
import CopyToClipboardButton from "./CopyToClipboardButton";


function WaitingRoom({roomID,userIsHost}) {;
    const [started, setRoomStarted] = React.useState();
    const [numberPetitions, setNumberPetitions] = React.useState();
    const navigate = useNavigate();

    const getIfRoomStarted = async () => {
        const path = HostPath.path + 'room/id/' + roomID
        await axios.get(path,{
            auth: {
              username: userAuthorized,
              password: passwordAuthorized
            }
          })
            .then(res => {
                let value = Object.values(res.data.room)
                var startedRoom = value.at(0).started
                console.log(numberPetitions+" " +res.status + " " + startedRoom)
                setNumberPetitions(numberPetitions+1)
                setRoomStarted(startedRoom)
            }).catch((error) => {
                console.log(error.message)
            });
    } 
    const putStartRoom = async () => {
        const path = HostPath.path + 'room' 
        const parameters = {
            started: true,
            id: roomID
        };
        console.log(parameters)
        await axios.put(path, parameters, {
            auth: {
              username: userAuthorized,
              password: passwordAuthorized
            }
          })
            .then(res => {
                console.log(res.data)
                console.log(res.status);
                if (res.status === 200) { // respuesta server is ok
                    console.log('put started in room success')
                    //start Wordle Multiplayer -> window.reload
                    setTimeout(function () { 
                        setRoomStarted(true)
                    }, 5000);
                }else {
                    console.log("put started in room failed");
                }
            }).catch((error) => {
                console.log(error.message)
            });
    }
    const handleSubmit = async () => {
        // put started 
        if (!started){
            await putStartRoom()
        }
    }
    
    useEffect(() => {
        console.log(userIsHost)
        if (!userIsHost){
            setTimeout(function () { 
                navigate("/multiplayer")
            }, 120000); //dos minuts de timeout per evitar exces de peticions
        }
        
        
    }, []);

    useEffect(() => {
        if (roomID){ 
            console.log(roomID)
            setNumberPetitions(1) //make the first check
        }
    }, [roomID]);

    useEffect(() => {
        if (numberPetitions < 12 && !started && !userIsHost){ 
            setTimeout(function () { 
                getIfRoomStarted()
            }, 10000);
        }
    }, [numberPetitions]);

    useEffect(() => {
        if (roomID){
            if (started){
                console.log("The Wordle Multiplayer has already started.")
                window.location.reload();
                //navigate("/wordle-multiplayer", {state:{roomID: roomID}})
            } else {
                console.log("The Wordle Multiplayer hasn't started.")
                
            }
        }
        
    }, [started]);

    return userIsHost ?(
        <div >
            <Box
                sx={{
                display: 'flex',
                flexDirection: 'column',
                justifyContent: 'center',
                p: 1,
                m: 1,
                borderRadius: 1,
                paddingTop:20
                }}
            >
                <div style={{marginBottom: "20px"}}>
                    Room ID: {roomID}
                    <CopyToClipboardButton roomID={roomID}/>
                </div>
                <button className="button" onClick={() => handleSubmit()}>
                    Start Game
                </button>
            </Box>
        </div> 
        ) : (
        <div >
            <Box
                sx={{
                display: 'flex',
                flexDirection: 'column',
                justifyContent: 'center',
                p: 1,
                m: 1,
                borderRadius: 1,
                paddingTop:20
                }}
            >
                <div style={{marginBottom: "20px"}}>
                    Room ID: {roomID}
                    <CopyToClipboardButton roomID={roomID}/>
                </div>
                <div>
                    Waiting for host to start the game...
                </div>
            </Box>
        </div> 
        
    );
}
export default WaitingRoom;