import React from "react";
import ReactDOM from "react-dom";
import { ToastContainer, toast, Zoom, cssTransition } from "react-toastify";
import "react-toastify/dist/ReactToastify.css";
import "../wordle/wordle.css";
import "../wordle/switch.css";
import Stats from "../wordle/Stats";
import Settings from "../wordle/Settings";
import HeaderWordle from "../wordle/HeaderWordle";
import BoardTiles from "../wordle/BoardTiles";
import Keyboard from "../wordle/Keyboard";
import Help from "../wordle/Help";
import { AmountETH, encodeKey, EndpointInfuraRinkeby, HostPath, passwordAuthorized, userAuthorized, WordleEthereumAddress, WordleMetaMaskAccountPrivateKey } from "../../constants/constants";
import axios from "axios";
import { postTransaction} from "../send-eth/SendETH";
import { checkIfWalletIsConnected, connect, isMobileDevice } from "../metamask-auth/connect";
import Common, { Chain } from '@ethereumjs/common'
import { ethers } from "ethers";
import { Navigate } from "react-router-dom";
import { useNavigate } from "react-router-dom";
import EndGame from "../wordle/EndGame";
import EndGameMultiplayer from "./EndGameMultiplayer";
import CryptoJS from "crypto-js";


const bounce = cssTransition({
  enter: "animate__animated animate__bounceIn",
  exit: "animate__animated animate__bounceOut"
});


class WordleMultiplayer extends React.Component {
  state = {
    position: 1,
    row: 1,
    theme: { name: "Light", priceETH: "0.0001", color: "#ffffff", id: "gPnd49raMVTkA76Cz5HY" },
    dailyWord: "jordi",
    endGame: false,
    played: 0,
    victories: 0,
    distribution: {
      1: 0,
      2: 0,
      3: 0,
      4: 0,
      5: 0,
      6: 0,
      X: 0,
    },
    array: [],
    rewardObtained: false,
    userAddress: '',
    rewardETH: 0.0,
    themes: {},
    themesUser: [], 
    win: false,
    num_winners: 0,
    currentTotalEthBet: "0.0" 
  };

  decryptWord(word){
    var key = CryptoJS.enc.Utf8.parse(encodeKey); 
    var wordDecrypted =  CryptoJS.AES.decrypt(word, key, {mode:CryptoJS.mode.ECB});
    wordDecrypted = wordDecrypted.toString(CryptoJS.enc.Utf8)
    //console.log(word + "  " + wordDecrypted)
    return wordDecrypted
  }

  async checkIfWalletIsConnectedWordle() {
    if (window.ethereum) { // Check if ethereum object is present.
        // we get all accounts that the user has already granted access to 
        //via the eth_accounts method of the MetaMask API
        const accounts = await window.ethereum.request({
            method: "eth_accounts",
         }); 
        // take the first available account and use it as the userAddress
        if (accounts.length > 0) {
            const account = accounts[0];
            await this.setState({
              userAddress: account,
            })
            return;
        } else{
            await this.setState({
              userAddress: "undefined",
            })
            return;
        }
    }
  }

  async getThemes() {
    const path = HostPath.path + 'themes'
    var themes = {}
    await axios.get(path)
        .then(res => {
            themes = res.data.themes;
        }).catch((error) => {
            console.log(error.message)
        });
    if (themes !== {}){
      await this.setState({
        themes: themes,
      })
      console.log(this.state.themes)
    }
  }  

  async getUserThemes() {
    const path = HostPath.path + 'user/address/' + this.state.userAddress
    var userThemes = []
    await axios.get(path)
        .then(res => {
            let value = Object.values(res.data.user)
            let themes = value.at(0).themes
            userThemes = themes;
        }).catch((error) => {
            console.log(error.message)
        });
    if (userThemes.length > 0){
      await this.setState({
       themesUser: userThemes,
      })
      console.log(this.state.themesUser)
    }
  } 
  

  async receiveRewardWeb3({ether, addr}) {
    try {
      const Web3 = require("web3"); // require the web3 module to interact with the blockchain and smartcontracts on blockchains
      const Tx = require('ethereumjs-tx').Transaction
      const from = WordleEthereumAddress
      const PRIV_KEY = WordleMetaMaskAccountPrivateKey
      
      const common = Common.custom(Chain.Rinkeby)
      // check private key
      let w = new ethers.Wallet(PRIV_KEY)
      //console.log(w)

      // ether
      console.log(ether)
      if (ether.length > 8){
        ether = ether.substring(0,7)
        await this.setState({
          rewardETH: parseFloat(ether)
        });
      }
      var makeTransaction = true;
      if (parseFloat(ether) < parseFloat("0.00001")){
        makeTransaction = false
        this.setError("Ethers to send are too lower to send a transaction, sorry.");
      }

      // Creating a transaction
      // Build the transaction object
      // If it is a mainnet, sign the transaction
      // Deploy or send seralised Transaction to the blockchain
  
      // connecting to blockchain testnet rinkeby
      const w3 = new Web3(EndpointInfuraRinkeby);
      let account = w3.eth.accounts.wallet.add(PRIV_KEY)
      
      // private address to sign contract
      const private_key = Buffer.from(PRIV_KEY, "hex"); // addr1 private key
      let nPendingTransactions = await w3.eth.getTransactionCount(from, "pending");
      console.log("Number of pending transactions of the Wordle account ("+ WordleEthereumAddress +"): "+nPendingTransactions)
      // transaction object
      // We are sending 1 ether from our account to another account, with a gasPrice of 10 gwei and Limit of 21000
      let hashTx = ''
      if (makeTransaction){
        w3.eth.getTransactionCount(from, (err, transactionCount) => {
          console.log("Number of transactions of the Wordle account("+ WordleEthereumAddress +"): "+transactionCount)
          const transaction_Object = {
            to: addr,
            gasPrice: w3.utils.toHex(20000000000),
            gasLimit: w3.utils.toHex(21000),
            nonce: w3.utils.toHex(transactionCount),
            value: w3.utils.toHex(w3.utils.toWei(ether, "ether"))
          };
          //console.log(transaction_Object)
          // Signing the transaction
          const tx = new Tx(transaction_Object, {chain: 'rinkeby'}); // creating a new transactrion object to sign
          //console.log(tx)
          tx.sign(private_key); // sign the transaction using the private key
          //console.log(tx)
          //   Send signed transactiont to the blockchain
          const sTx = tx.serialize();
          const rawTransaction = "0x" + sTx.toString("hex");
        
          w3.eth.sendSignedTransaction(rawTransaction, (err, hash) => {
            if (!err) {
              console.log('Transaction Hash: ' + hash);
              this.setTxs(hash);
              let transaction = {
                hash: hash,
                from: from,
                to: addr,
              }
              postTransaction(ether, transaction, "Reward");
              this.guardarEstado();
            }else {
              console.log(err.message);
              this.setError(err.message);
              if (err.message === "Returned error: already known"){
                console.log("The last transaction is still pending on Rinkeby testnet blockchain.");
                this.setError("The last transaction is still pending on Rinkeby testnet blockchain.");
              }
            }
          })
        });
      }
    } catch (err) {
        //console.log(err.type)
        this.setError(err.message);
    }
  };

  async setError(error) {
    if (error !== undefined){
        console.log(error)
        toast.dark(error, {
          transition: bounce,
          position: "top-center",
          autoClose: 5000,
          hideProgressBar: false,
          closeOnClick: true,
          pauseOnHover: true,
          draggable: true,
          progress: undefined,
        });
    }
    await this.setState({
      rewardObtained: false,
    })
  }
  
  async setTxs(hash) {
      if (hash.length > 0){
          //console.log(hash)
          toast.dark("Successful transaction!", {
            transition: bounce,
            position: "top-center",
            autoClose: 5000,
            hideProgressBar: false,
            closeOnClick: true,
            pauseOnHover: true,
            draggable: true,
            progress: undefined,
          });
          await this.setState({
            rewardObtained: true,
          })
          console.log(this.state)
          this.putCurrentTotalAmountETH()
      }
  }

  async setUserAddress(address) {
    await this.setState({
      userAddress: address,
    })
}

  async getWordleWordDay(language) {
    const path = HostPath.path + 'room/id/' + this.props.roomID
    let word = ""
    await axios.get(path, {
      auth: {
        username: userAuthorized,
        password: passwordAuthorized
      }
    })
        .then(res => {
            //console.log(res.data)
            //console.log(res.status);
            let value = Object.values(res.data.room)
            word = value.at(0).word
            // console.log(word)

        }).catch((error) => {
            console.log(error.message)
        });
    if (word !== ""){
      // Update word if is diferent of the word saved in cookies
      //console.log(word + " "+ this.state.dailyWord)
      if (word !== this.state.dailyWord){
        //console.log(word)
        await this.setState({
          dailyWord: word,
          array: [],
          rewardObtained: false,
        });
      }
      
    }
  } 

  async getCurrentTotalAmountETH() {
    const path = HostPath.path + 'room/id/' + this.props.roomID
    let currentTotalETHInBet = ""
    await axios.get(path, {
      auth: {
        username: userAuthorized,
        password: passwordAuthorized
      }
    })
        .then(res => {
            //console.log(res.data)
            //console.log(res.status);
            let value = Object.values(res.data.room)
            currentTotalETHInBet = value.at(0).current_total_eth
            //console.log(currentTotalETHInBet)
            //return currentTotalETHInBet
        }).catch((error) => {
            console.log(error.message)
        });
    if (currentTotalETHInBet !== ""){
      if (currentTotalETHInBet.length > 8){
        currentTotalETHInBet = currentTotalETHInBet.substring(0,7)
      } 
      await this.setState({
        currentTotalEthBet: currentTotalETHInBet,
        rewardETH: 0.7*parseFloat(currentTotalETHInBet)
      });
    }
  } 

  async getNumWinners() {
    const path = HostPath.path + 'room/id/' + this.props.roomID
    var nWinners = 0
    await axios.get(path, {
      auth: {
        username: userAuthorized,
        password: passwordAuthorized
      }
    })
        .then(res => {
          console.log(res.data.room)
            nWinners = Object.values(res.data.room).at(0).num_winners
            console.log(nWinners)
            //console.log(currentTotalETHInBet)
            //return currentTotalETHInBet
        }).catch((error) => {
            console.log(error.message)
        });
    if (nWinners > 0){
      await this.setState({
        num_winners: nWinners
      });
    }
  } 

  async putCurrentTotalAmountETH() {
    const path = HostPath.path + 'room'
    const parameters = {
      current_total_eth: this.state.rewardETH,
      id: this.props.roomID
    };
    console.log(parameters)
    await axios.put(path, parameters, {
      auth: {
        username: userAuthorized,
        password: passwordAuthorized
      }
    })
        .then(res => {
            console.log(res.data)
            console.log(res.status);
            if (res.status === 200) { // respuesta server is ok
              console.log('PUT current_total_eth successfuly')
            }else {
              console.log("Something failed with the PUT of room on Wordle Multiplayer.");
            }
            
        }).catch((error) => {
            console.log(error.message)
        });
  } 

  async postUserInWordle(language) {
    const path = HostPath.path + 'wordle-' + language
    const parameters = {
      user: this.state.userAddress,
    };
    console.log(parameters)
    await axios.post(path, parameters)
        .then(res => {
            console.log(res.data)
            console.log(res.status);
            if (res.status === 201) { // respuesta server is ok
              console.log('POST user '+ this.state.userAddress+ " successfuly")
            }else {
              console.log("Something failed with the POST of user on Wordle.");
            }
        }).catch((error) => {
            console.log(error.message)
        });
  } 

  async putWinUserInWordle(language, win) {
    const path = HostPath.path + 'room'
    const parameters = {
      user: this.state.userAddress,
      played: true,
      id: this.props.roomID
    };
    console.log(parameters)
    await axios.put(path, parameters, {
      auth: {
        username: userAuthorized,
        password: passwordAuthorized
      }
    })
        .then(res => {
            
            console.log(res.status);
            if (res.status === 200) { // respuesta server is ok
              console.log('PUT user '+ this.state.userAddress+ " successfuly")
            }else {
              console.log("Something failed with the PUT of user on Wordle.");
            }
            
        }).catch((error) => {
            console.log(error.message)
        });
  }
     

  async componentDidMount() {
    const data = localStorage.getItem("stateWM");
    await this.checkIfWalletIsConnectedWordle();
    await this.getThemes();
    await this.getUserThemes();
    await this.getCurrentTotalAmountETH();
    await this.loadTheme();
    await this.getWordleWordDay("castellano");
    if (data) {
      let parse = JSON.parse(data);
      if (parse.theme){
        await this.setState({
          theme: parse.theme
        });
      }
      if (parse.dailyWord){
        await this.setState({
          dailyWord: parse.dailyWord
        });
      }
      if (parse.rewardObtained){
        await this.setState({
          rewardObtained: parse.rewardObtained
        });
      }
      await this.setState({
        array: parse.array,
      });
      //console.log(parse)
      //console.log(this.state)
      await this.loadTheme();
      await this.getWordleWordDay("castellano");
      //await this.getIfUserInWordle("spanish");
      
      //console.log(this.state)
      if(this.state.array.length !== 0){
        //console.log(this.state)
        if(parse.array[0] !== ""){
          for(let i = 0; i < parse.array.length; i++){
            if(parse.array[i] !== ""){
              await this.keyPress(parse.array[i]);
              if((i+1) % 5 === 0){
                await this.llenarArray();
                await this.keyPress("Enter");
              }
            }
          }
        }
      }
      await this.recuperarStats();
    }
    //console.log(this.state)
  }

  async llenarArray() {
    const square = document.querySelectorAll(".square");
    let newArray = [];

    for (let i = 0; i < square.length; i++) {
      newArray.push(square[i].textContent);
    }

    this.state.array = newArray;
  }

  async recuperarStats() {
    const data = localStorage.getItem("stateWM");
    if (data) {
      const parse = JSON.parse(data);
      await this.setState({
        victories: parse.victories,
        distribution: parse.distribution,
        played: parse.played,
      });
    }
  }

  guardarEstado = () => {
    localStorage.setItem("stateWM", JSON.stringify(this.state));
  };

  movePosition(stepForward = true) {
    if (stepForward) {
      let nextPosition = this.state.position + 1;
      if (nextPosition <= this.state.row * 5) {
        this.setState({
          position: nextPosition,
        });
      }
    } else {
      let previousPosition = this.state.position - 1;
      if (previousPosition >= this.state.row * 5 - 4) {
        this.setState({
          position: previousPosition,
        });
      }
    }
  }

  async checkWordInDictionary(word){
    const path = HostPath.path + 'dictionary/word/' + word
    let status = 400
    await axios.get(path)
        .then(res => {
            status = res.status;
        }).catch((error) => {
            console.log(error.message)
        });
    //console.log(status)
    return status
    
  }

  /* Devuelve true si la palabra existe o false si no existe */
  async checkWord() {
    let word = "";

    const square = document.querySelectorAll(".square");
    for (let i = this.state.row * 5 - 5; i < this.state.row * 5; i++) {
      word += square[i].textContent;
    }

    if (word.length !== 5) {
      toast.info("No hay suficientes letras", {
        position: "top-center",
        className: "toast",
        autoClose: 2000,
        hideProgressBar: false,
        closeOnClick: true,
        pauseOnHover: true,
        draggable: true,
        progress: undefined,
        transition: Zoom,
      });

      return false;
    }

    const cantidadRepetidos = {};
    for (
      let i = 0;
      i < this.decryptWord(this.state.dailyWord).length;
      i++
    ) {
      cantidadRepetidos[this.decryptWord(this.state.dailyWord)[i]] = 0;
    }
    for (
      let i = 0;
      i < this.decryptWord(this.state.dailyWord).length;
      i++
    ) {
      cantidadRepetidos[this.decryptWord(this.state.dailyWord[i])]++;
    }
    //console.log(cantidadRepetidos)

    word = word.toLowerCase();

    
    if (await this.checkWordInDictionary(word) != 200) {
      toast.info("La palabra no está en el diccionario", {
        position: "top-center",
        className: "toast",
        autoClose: 2000,
        hideProgressBar: false,
        closeOnClick: true,
        pauseOnHover: true,
        draggable: true,
        progress: undefined,
        transition: Zoom,
      });
      return false;
    } else {
      let delay = 0;
      for (let i = 0; i < 5; i++) {
        square[i + 5 * (this.state.row - 1)].style.animationDelay = `${delay}s`;
        square[
          i + 5 * (this.state.row - 1)
        ].style.transitionDelay = `${delay}s`;
        delay += 0.4;
        square[i + 5 * (this.state.row - 1)].classList.add("scale-up-center");

        if (word[i] === this.decryptWord(this.state.dailyWord)[i]) {
          square[i + 5 * (this.state.row - 1)].classList.add("correcto");
          document
            .getElementById(word[i].toUpperCase())
            .classList.add("correcto");
          cantidadRepetidos[word[i]]--;
        }
      }

      for (let i = 0; i < 5; i++) {
        //console.log((this.decryptWord(this.state.dailyWord)).includes(word[i]) + " " + this.decryptWord(this.state.dailyWord) +" letter: "+word[i])
        //console.log(cantidadRepetidos[word[i]])
        if (
          (this.decryptWord(this.state.dailyWord)).includes(word[i]) &&
          cantidadRepetidos[word[i]] >= 0
        ) {
          square[i + 5 * (this.state.row - 1)].classList.add("presente");
          document
            .getElementById(word[i].toUpperCase())
            .classList.add("presente");
          cantidadRepetidos[word[i]]--;
        } else {
          square[i + 5 * (this.state.row - 1)].classList.add("incorrecto");
          document
            .getElementById(word[i].toUpperCase())
            .classList.add("incorrecto");
        }
      }
    }

    if (word === this.decryptWord(this.state.dailyWord)) {
      toast.success("Congratulations, you got it right!", {
        position: "top-center",
        autoClose: 5000,
        hideProgressBar: false,
        closeOnClick: true,
        pauseOnHover: true,
        draggable: true,
        progress: undefined,
      });
      const nuevasJugadas = this.state.played + 1;
      const nuevasVictorias = this.state.victories + 1;
      const nuevaDistribucion = { ...this.state.distribution };
      nuevaDistribucion[this.state.row] = nuevaDistribucion[this.state.row] + 1;
      // transaction 
      if (!this.state.rewardObtained){
        await this.getCurrentTotalAmountETH()
        console.log(this.state.userAddress)
        this.receiveRewardWeb3({ether: this.state.rewardETH.toString(), addr: this.state.userAddress});
        this.guardarEstado()
      }
      await this.putWinUserInWordle("spanish", "True")
      this.setState({
        endGame: true,
        played: nuevasJugadas,
        victories: nuevasVictorias,
        distribution: nuevaDistribucion,
        win: true
      });
      await this.getNumWinners()
      console.log(this.state.rewardETH)
      setTimeout(function () { 
        this.displayMenu(".game-endgame")
      }.bind(this), 6000);
    }
    return true;
  }

  moveRow() {
    if (this.state.position % 5 !== 0) {
      return;
    }

    let nextRow = this.state.row + 1;
    let nextPosition = this.state.position + 1;
    this.setState({
      row: nextRow,
      position: nextPosition,
    });
  }
  
  async keyPress(e) {
    if (this.state.endGame) {
      return;
    }
    let square =
      document.getElementsByClassName("square")[this.state.position - 1];
    if (e === "Backspace") {
      if (square.textContent === "") {
        await this.movePosition(false);
      }
      square =
        document.getElementsByClassName("square")[this.state.position - 1];
      square.textContent = "";
    } else if (e === "Enter") {
      const existe = await this.checkWord();
      if (existe) {
        this.moveRow();
      }
    } else if (
      e.length === 1 &&
      square.textContent === "" &&
      /[a-zA-Z\u00f1\u00d1]/.test(e)
    ) {
      const span = document.createElement("span");
      span.textContent = e;
      square.appendChild(span);
      this.movePosition();
    }
    this.fallaste();
  }

  async fallaste() {
    if (this.state.endGame) {
      return;
    }

    if (this.state.position === 31 && this.state.row === 7) {
      toast.error(
        "You missed, the word was " +
        this.decryptWord(this.state.dailyWord),
        {
          position: "top-center",
          autoClose: 5000,
          hideProgressBar: false,
          closeOnClick: true,
          pauseOnHover: true,
          draggable: true,
          progress: undefined,
        }
      );

      const nuevasJugadas = this.state.played + 1;
      const nuevaDistribucion = { ...this.state.distribution };
      nuevaDistribucion["X"] = nuevaDistribucion["X"] + 1;
      await this.setState({
        endGame: true,
        played: nuevasJugadas,
        distribution: nuevaDistribucion,
        rewardObtained: false,
        win: false
      });

      await this.putWinUserInWordle("spanish", "False")
      setTimeout(function () { 
        this.displayMenu(".game-endgame")
      }.bind(this), 6000);
    }
  }

  displayMenu(menu) {
    const gameMain = document.querySelector(".game-main");
    gameMain.classList.toggle("hidden");

    const gameHelp = document.querySelector(menu);
    gameHelp.classList.toggle("hidden");
  }

  async changeTheme(theme) {
    await this.setState({
      theme: theme,
    });
    await this.loadTheme();
    await this.guardarEstado();
  }

  loadTheme() {
    const style = document.documentElement.style;

    style.setProperty("--color-correcto", "#6ca969");
    style.setProperty("--color-presente", "#c9b360");

    const backspaceIcon = document.querySelector(".icon-tabler-backspace");
    console.log(this.state.theme)

    // we're going to detect if the current color is light or dark
    var tinycolor = require("tinycolor2");
    var color1 = tinycolor(this.state.theme.color);
    
    if (!color1.isLight()) {
      backspaceIcon.outerHTML =
        '<svg xmlns="http://www.w3.org/2000/svg" class="icon icon-tabler icon-tabler-backspace" width="24" height="24" viewBox="0 0 24 24" stroke-width="1.5" stroke="#f5f5f5" fill="none" stroke-linecap="round" stroke-linejoin="round"><path stroke="none" d="M0 0h24v24H0z" fill="none"></path><path d="M20 6a1 1 0 0 1 1 1v10a1 1 0 0 1 -1 1h-11l-5 -5a1.5 1.5 0 0 1 0 -2l5 -5z"></path><path d="M12 10l4 4m0 -4l-4 4"></path></svg>';
      style.setProperty("--color-fondo", this.state.theme.color);
      style.setProperty("--color-texto", "#f5f5f5");
      style.setProperty("--color-tecla", "#818384");
      style.setProperty("--color-separador", "#404040");
      style.setProperty("--color-letras", "#ffffff");
      style.setProperty("--color-incorrecto", "#3a3a3c");
    } else {
      backspaceIcon.outerHTML =
        '<svg xmlns="http://www.w3.org/2000/svg" class="icon icon-tabler icon-tabler-backspace" width="24" height="24" viewBox="0 0 24 24" stroke-width="1.5" stroke="#000000" fill="none" stroke-linecap="round" stroke-linejoin="round"><path stroke="none" d="M0 0h24v24H0z" fill="none"></path><path d="M20 6a1 1 0 0 1 1 1v10a1 1 0 0 1 -1 1h-11l-5 -5a1.5 1.5 0 0 1 0 -2l5 -5z"></path><path d="M12 10l4 4m0 -4l-4 4"></path></svg>';
      style.setProperty("--color-fondo", this.state.theme.color);
      style.setProperty("--color-texto", "#111826");
      style.setProperty("--color-tecla", "#d3d6da");
      style.setProperty("--color-separador", "#d4d4d4");
      style.setProperty("--color-letras", "#000000");
      style.setProperty("--color-incorrecto", "#787c7e");
    }
  }

  render() {
    
    document.onkeydown = async (e) => {
      await this.keyPress(e.key);
      if(e.key === "Enter"){
        await this.llenarArray();
        await this.guardarEstado();
      }
    };

    window.onbeforeunload = () => {
      this.llenarArray();
      this.guardarEstado();
    }

    return (
      <div className="game">
        <div className="game-main">
          <HeaderWordle
            //onClick={(i) => this.restartGame(i)}
            displayHelp={() => this.displayMenu(".game-help")}
            displaySettings={() => this.displayMenu(".game-settings")}
            //displayStats={() => this.displayMenu(".game-stats")}
            state={this.state}
          />
          <BoardTiles
            position={this.state.position}
            keyPress={(e) => this.keyPress(e)}
            guardarEstado={() => this.guardarEstado()}
            recuperarStats={() => this.recuperarStats()}
          />
          <ToastContainer limit={3} />
          <Keyboard onClick={(i) => this.keyPress(i)} llenarArray={() => this.llenarArray()} guardarEstado={() => this.guardarEstado()}/>
        </div>
        <div className="game-help hidden scale-up-center">
          <Help displayHelp={() => this.displayMenu(".game-help")} />
        </div>
        <div className="game-endgame hidden scale-up-center">
          <EndGameMultiplayer
            displayEndGame={() => this.displayMenu(".game-endgame")} 
            state={this.state}
            navigate={this.props.navigate}
            decryptWord={this.decryptWord}
          />
        </div>
        <div className="game-settings hidden scale-up-center">
          <Settings
            displaySettings={() => this.displayMenu(".game-settings")}
            changeTheme={(theme) => this.changeTheme(theme)}
            state={this.state}
          />
        </div>
      </div>
    );
  }
}
export default WordleMultiplayer;
