import { Navigate, useNavigate } from "react-router-dom";
import React, { useEffect, useState } from "react";
import { receiveFreeEthereum, startPayment } from "../send-eth/SendETH";
import { ethers } from "ethers";
import { checkIfWalletIsConnected } from "../metamask-auth/connect";
import { addressWordleETH, AmountETH, AmountETHObtainCrypto, HostPath, passwordAuthorized, userAuthorized } from "../../constants/constants";
import "animate.css/animate.min.css";
import { ToastContainer, toast, cssTransition } from "react-toastify";
import { Container } from '@material-ui/core';
import axios from 'axios';


const bounce = cssTransition({
    enter: "animate__animated animate__bounceIn",
    exit: "animate__animated animate__bounceOut"
});

function RequestObtainCrypto({ setUserAlreadyRequested, userAlreadyRequested, setRequestDate}) {
    const navigate = useNavigate();
    const [error, setError] = useState();
    const [txs, setTxs] = useState([]);

    const [userAddress, setUserAddress] = useState("");
    const [loaded, setLoaded] = useState(false);
    const [loading, setLoading] = useState(false);

    const getIfUserRequested = async () => {
        const path = HostPath.path + 'obtain-crypto/address/' + userAddress
        await axios.get(path)
            .then(res => {
                if (res.status === 200){
                    let value = Object.values(res.data.user_request)
                    let date = value.at(0).date
                    setRequestDate(date)
                    setUserAlreadyRequested(true)
                }
            }).catch((error) => {
                console.log(error.message)
                if (error.status === 404){
                    setUserAlreadyRequested(false)
                }
            });
    } 

    const postUserInObtainCrypto = async () => {
        const path = HostPath.path + 'obtain-crypto'
        const parameters = {
            user: userAddress,
            amount_eth: AmountETHObtainCrypto
        };
        console.log(parameters)
        await axios.post(path, parameters, {
            auth: {
              username: userAuthorized,
              password: passwordAuthorized
            }
          })
            .then(res => {
                console.log(res.data)
                console.log(res.status);
                if (res.status === 201) { // respuesta server is ok
                    console.log('¡Todo bien!')
                    let value = Object.values(res.data.user_request)
                    let date = value.at(0).date
                    setRequestDate(date)
                    setLoading(true)
                    setTimeout(function () { 
                        //window.location.reload()
                        //navigate("/obtain-cryptos");
                        setUserAlreadyRequested(true)
                    }, 6000);
                    
                }else {
                    console.log("¡Algo ha ocurrido!");
                    setUserAlreadyRequested(false)
                }
            }).catch((error) => {

                console.log(error.message)
            });
    } 

    useEffect(()=>{
        if (error !== undefined){
            console.log(error)
            toast.dark(error, {transition: bounce});
        }
    },[error])
    
    useEffect(()=>{
        if (txs.length > 0){
            console.log(txs)
            toast.dark("Successful transaction!", {transition: bounce});
            // put 
            postUserInObtainCrypto()
        }
    },[txs])

    useEffect(() => {
        checkIfWalletIsConnected(setUserAddress);
    }, []);

    useEffect(() => {
        if (userAddress!==""){
            try{
                console.log(userAddress)
                ethers.utils.getAddress(userAddress);
                setLoaded(true)
            } catch (err) {
                Navigate("/");
            }
        }
    }, [userAddress]);

    useEffect(() => {
        if (loaded){
            //getIfUserRequested()
            console.log(userAlreadyRequested)
        }
    }, [loaded]);
    
    const handleSubmit = async () => {
        if (!userAlreadyRequested){
            await receiveFreeEthereum({setError, setTxs, ether: AmountETHObtainCrypto.toString(), addr: userAddress});
        }
    }

    return (
        <Container>
            <ToastContainer className="toast" transition={bounce} />
            <button className="button" onClick={() => handleSubmit()} disabled={loading}>
                Obtain Crypto
            </button>
        </Container>
    );
}
export default RequestObtainCrypto;