import { useEffect, useState } from "react";
import { ethers } from "ethers";
import "animate.css/animate.min.css";
import "react-toastify/dist/ReactToastify.css";
import { ToastContainer, toast, cssTransition } from "react-toastify";
import { Card, CardActions, CardContent, Container, makeStyles } from "@material-ui/core";
import "./styles.css";
import { EndpointInfuraRinkeby, HostPath, passwordAuthorized, userAuthorized, WordleEthereumAddress, WordleEthereumAddress2, WordleMetaMaskAccountPrivateKey, WordleMetaMaskAccountPrivateKey2 } from "../../constants/constants";
import axios from 'axios';
import { Transaction } from '@ethereumjs/tx'
import Common, { Chain } from '@ethereumjs/common'
import Web3 from "web3";

const bounce = cssTransition({
    enter: "animate__animated animate__bounceIn",
    exit: "animate__animated animate__bounceOut"
});

const useStyles = makeStyles({
    card: {
      maxWidth: 345,
      boxShadow: "0 5px 8px 0 rgba(0, 0, 0, 0.3)",
      backgroundColor: "#fafafa",
    },
  });

const postTransaction = async (ether, txs, type) => {
  const path = HostPath.path + 'transaction/sender/' + txs.from
  const parameters = {
    hash: txs.hash,
    type: type,
    sender: txs.from,
    receiver: txs.to,
    amount_eth: ether
  };
  //console.log(parameters)
  await axios.post(path, parameters, {
    auth: {
      username: userAuthorized,
      password: passwordAuthorized
    }
  })
      .then(res => {
          //console.log(res.data)
          //console.log(res.status);
          if (res.status === 201) { // respuesta server is ok
            console.log('POST transaction successful')
          }else {
            console.log("Something goes wrong with the POST of the transaction");
          }
      }).catch((error) => {
          console.log(error.message)
      });
}
export {postTransaction};

const startPayment = async ({ setError, setTxs, ether, addr }) => {
    try {
        if (!window.ethereum){
            throw new Error("No crypto wallet found. Please install it.");
        }
        
        const accounts = await window.ethereum.request({
            method: "eth_accounts",
        }); 
        const provider = new ethers.providers.Web3Provider(window.ethereum);
        const signer = provider.getSigner();
        ethers.utils.getAddress(addr); // throw error
        const tx = await signer.sendTransaction({
            to: addr,
            value: ethers.utils.parseEther(ether)
        });
        console.log({ ether, addr });
        console.log("tx", tx);
        setTxs([tx]);
        await postTransaction(ether, tx, "Payment")
    } catch (err) {
      if (err.message.substring(0,49) === "insufficient funds for intrinsic transaction cost"){
        setError("There are no funds. You can get free funds in the 'Obtain Cryptos' section!")
      } else{
        setError(err.message);
      }
    }
};
export {startPayment}

const startRewardWeb3 = async ({ setError, setTxs, ether, addr }) => {
  try {
    const Web3 = require("web3"); // require the web3 module to interact with the blockchain and smartcontracts on blockchains
    const Tx = require('ethereumjs-tx').Transaction
    const from = WordleEthereumAddress
    const PRIV_KEY = WordleMetaMaskAccountPrivateKey

    const common = Common.custom(Chain.Rinkeby)
    // check private key
    let w = new ethers.Wallet(PRIV_KEY)
    // console.log(w)
    // Creating a transaction
    // Build the transaction object
    // If it is a mainnet, sign the transaction
    // Deploy or send seralised Transaction to the blockchain

    // connecting to blockchain testnet rinkeby
    const w3 = new Web3(EndpointInfuraRinkeby);
    let account = w3.eth.accounts.wallet.add(PRIV_KEY)
    
    // private address to sign contract
    const private_key = Buffer.from(PRIV_KEY, "hex"); // addr1 private key
    let nPendingTransactions = await w3.eth.getTransactionCount(from, "pending");
    console.log("Number of pending transactions of the Wordle account: "+nPendingTransactions)
    // transaction object
    // We are sending 1 ether from our account to another account, with a gasPrice of 10 gwei and Limit of 21000
    
    w3.eth.getTransactionCount(from, (err, transactionCount) => {
      console.log("Number of transactions of the Wordle account: "+transactionCount)
      const transaction_Object = {
        to: addr,
        gasPrice: w3.utils.toHex(10000000000),
        gasLimit: w3.utils.toHex(21000),
        nonce: w3.utils.toHex(transactionCount),
        value: w3.utils.toHex(w3.utils.toWei(ether, "ether"))
      };
      console.log(transaction_Object)
      // Signing the transaction
      const tx = new Tx(transaction_Object, {chain: 'rinkeby'}); // creating a new transactrion object to sign
      console.log(tx)
      tx.sign(private_key); // sign the transaction using the private key
      console.log(tx)
      //   Send signed transactiont to the blockchain
      const sTx = tx.serialize();
      const rawTransaction = "0x" + sTx.toString("hex");
    
      w3.eth.sendSignedTransaction(rawTransaction, (err, hash) => {
        if (!err) {
          console.log('Tx Hash: ' + hash);
          setTxs(hash);
        }else {
          console.log(err.message);
          if (err.message === "Returned error: already known"){
            console.log("The last transaction is still pending on Rinkeby testnet blockchain.");
          }
        }
      })

      //await postTransaction(ether, tx, "Payment")
      
    });
  } catch (err) {
      //console.log(err.type)
      setError(err.message);
  }
};
export {startRewardWeb3}

const receiveFreeEthereum = async ({ setError, setTxs, ether, addr }) => {
  try {
    const Web3 = require("web3"); // require the web3 module to interact with the blockchain and smartcontracts on blockchains
    const Tx = require('ethereumjs-tx').Transaction
    const from = WordleEthereumAddress2
    const PRIV_KEY = WordleMetaMaskAccountPrivateKey2

    const common = Common.custom(Chain.Rinkeby)
    // check private key
    let w = new ethers.Wallet(PRIV_KEY)
    // console.log(w)
    // Creating a transaction
    // Build the transaction object
    // If it is a mainnet, sign the transaction
    // Deploy or send seralised Transaction to the blockchain

    // connecting to blockchain testnet rinkeby
    const w3 = new Web3(EndpointInfuraRinkeby);
    let account = w3.eth.accounts.wallet.add(PRIV_KEY)
    
    // private address to sign contract
    const private_key = Buffer.from(PRIV_KEY, "hex"); // addr1 private key
    let nPendingTransactions = await w3.eth.getTransactionCount(from, "pending");
    console.log("Number of pending transactions of the Wordle account: "+nPendingTransactions)
    // transaction object
    // We are sending 1 ether from our account to another account, with a gasPrice of 10 gwei and Limit of 21000
    
    w3.eth.getTransactionCount(from, (err, transactionCount) => {
      console.log("Number of transactions of the Wordle account: "+transactionCount)
      const transaction_Object = {
        to: addr,
        gasPrice: w3.utils.toHex(20000000000),
        gasLimit: w3.utils.toHex(21000),
        nonce: w3.utils.toHex(transactionCount),
        value: w3.utils.toHex(w3.utils.toWei(ether, "ether"))
      };
      //console.log(transaction_Object)
      // Signing the transaction
      const tx = new Tx(transaction_Object, {chain: 'rinkeby'}); // creating a new transactrion object to sign
      //console.log(tx)
      tx.sign(private_key); // sign the transaction using the private key
      //console.log(tx)
      //   Send signed transactiont to the blockchain
      const sTx = tx.serialize();
      const rawTransaction = "0x" + sTx.toString("hex");
    
      w3.eth.sendSignedTransaction(rawTransaction, (err, hash) => {
        if (!err) {
          console.log('Tx Hash: ' + hash);
          setTxs(hash);
          let transaction = {
            hash: hash,
            from: from,
            to: addr,
          }
          postTransaction(ether, transaction, "Obtain Crypto")
        }else {
          if (err.message === "Returned error: already known"){
            console.log("The last transaction is still pending on Rinkeby testnet blockchain.");
            setError("The last transaction is still pending on Rinkeby testnet blockchain.");
          } else{
            console.log(err.message);
            setError(err.message);
          }
        }
      })      
    });
  } catch (err) {
      //console.log(err.type)
      setError(err.message);
  }
};
export {receiveFreeEthereum}

export default function SendETH() {
  const [error, setError] = useState();
  const [txs, setTxs] = useState([]);
  const classes = useStyles();
  useEffect(()=>{
    if (error !== undefined){
        console.log(error)
        toast.dark(error, {transition: bounce});
    }
  },[error])

  useEffect(()=>{
    if (txs.length > 0){
        console.log(txs)
        toast.dark("Successful transaction!", {transition: bounce});
    }
  },[txs])

  const handleSubmit = async (e) => {
    e.preventDefault();
    const data = new FormData(e.target);
    setError();
    await startPayment({
      setError,
      setTxs,
      ether: data.get("ether"),
      addr: data.get("addr")
    });
  };

  

  return (
      <Container>
      <ToastContainer className="toast" transition={bounce} />
        
    <div className='center'>
        <div className="form">
        <form onSubmit={handleSubmit}>
            <div className="title">
                Send ETH
            </div>
            <div className="input-container ic1">
                <input
                    type="text"
                    name="addr"
                    className="input"
                    placeholder=" "
                />
                <div className="cut cut-long"></div>
                <label className="placeholder">Recipient Address</label>
                
            </div>
            <div className="input-container ic2">
                <input
                        name="ether"
                        type="text"
                        className="input"
                        placeholder=" "
                    />
                    <div className="cut cut-long-shorter"></div>
                    <label className="placeholder">Amount in ETH</label>
            </div>
            <button type="text" className="submit">SEND</button>
        </form>
        </div>
    </div>
    </Container>
  );
}
