import React, { useEffect, useState } from "react";

import axios from 'axios';
import JoinedWordle from "./JoinedWordle";
import JoinWordleBet from "./JoinWordleBet";
import { checkIfWalletIsConnected } from "../metamask-auth/connect";
import { ethers } from "ethers";
import { Navigate } from "react-router-dom";
import { useNavigate } from "react-router-dom";
import { AmountETH, HostPath, passwordAuthorized, userAuthorized } from "../../constants/constants";

function HomeWordle() {
  const [userInTodayBet, setUserInTodayBet] = useState();
  const [userInNextBet, setUserInNextBet] = useState();
  const [betTodayExists, setTodayBetExists] = useState();
  const [betNextExists, setNextBetExists] = useState();
  const [userAddress, setUserAddress] = useState("");
  const [loaded, setLoaded] = useState(false);
  const [nextBetDate, setNextBetDate] = useState("");
  const [userNotPlayedWordle, setUserNotPlayedWordle] = useState()

  const navigate = useNavigate();

  useEffect(() => {
    checkIfWalletIsConnected(setUserAddress);
    // checked when the page loads the first time
  }, []);

  useEffect(() => {
    if (userAddress!==""){
      try{
        console.log(userAddress)
        ethers.utils.getAddress(userAddress);
        setLoaded(true)
      } catch (err) {
        Navigate("/");
      }
    }
  }, [userAddress]);

  const getIfTodayBetExists = async () => {
    const path = HostPath.path + 'bet'
    await axios.get(path)
        .then(res => {
            console.log(res.data)
            console.log(res.status);
            setTodayBetExists(true)
        }).catch((error) => {
            console.log(error.message)
            setTodayBetExists(false)
        });
  } 

  const getIfNextBetExists = async () => {
    const path = HostPath.path + 'bet/date/' + 'next'
    await axios.get(path)
        .then(res => {
            console.log(res.data)
            console.log(res.status);
            setNextBetExists(true)
        }).catch((error) => {
            console.log(error.message)
            setNextBetExists(false)
        });
  } 

  const postTodayBet = async () => {
    const path = HostPath.path + 'bet'
    const parameters = {
      amount_eth: AmountETH
    };
    console.log(parameters)
    await axios.post(path, parameters)
        .then(res => {
            console.log(res.data)
            console.log(res.status);
            if (res.status === 201) { // respuesta server is ok
              console.log('¡Todo bien!')
              setTodayBetExists(true)
            }else {
              console.log("¡Algo ha ocurrido!");
              setTodayBetExists(false)
            }
        }).catch((error) => {
            console.log(error.message)
        });
  } 

  const postNextBet = async () => {
    const path = HostPath.path + 'bet/date/' + 'next'
    const parameters = {
      amount_eth: AmountETH
    };
    console.log(parameters)
    await axios.post(path, parameters, {
      auth: {
        username: userAuthorized,
        password: passwordAuthorized
      }
    })
        .then(res => {
            console.log(res.data)
            console.log(res.status);
            if (res.status === 201) { // respuesta server is ok
              console.log('¡Todo bien!')
              setNextBetExists(true)
            }else {
              console.log("¡Algo ha ocurrido!");
              setNextBetExists(false)
            }
        }).catch((error) => {
            console.log(error.message)
        });
  } 

  const getIfUserAlreadyInTodayBet = async () => {
    const path = HostPath.path + 'bet'
    await axios.get(path)
        .then(res => {
            //console.log(res.data)
            //console.log(res.status);
            let value = Object.values(res.data.bet)
            let users = value.at(0).users
            if (users.includes(userAddress)) {
              setUserInTodayBet(true)
              console.log("User is already in today's bet.")
            }else{
              setUserInTodayBet(false)
              console.log("User isn't already in today's bet.")
            }
        }).catch((error) => {
            console.log(error.message)
        });
  } 

  const getIfUserAlreadyInNextBet = async () => {
    const path = HostPath.path + 'bet/date/' + 'next'
    await axios.get(path)
        .then(res => {
            //console.log(res.data)
            //console.log(res.status);
            let value = Object.values(res.data.bet)
            let users = value.at(0).users
            if (users.includes(userAddress)) {
              setUserInNextBet(true)
              console.log("User is already in next bet.")
            }else{
              setUserInNextBet(false)
              console.log("User isn't already in next bet.")
            }
        }).catch((error) => {
            console.log(error.message)
        });
  } 

  const getDateNextBet = async () => {
    const path = HostPath.path + 'bet/date/' + 'next'
    await axios.get(path)
        .then(res => {
            //console.log(res.data)
            //console.log(res.status);
            let value = Object.values(res.data.bet)
            setNextBetDate(value.at(0).bet_date)
        }).catch((error) => {
            console.log(error.message)
        });
  } 

  const getIfUserAlreadyPlayedThisWordle = async () => {
    const path = HostPath.path + 'wordle-spanish/address/' + userAddress
    console.log(path)
    await axios.get(path)
        .then(res => {
            //console.log(res.data)
            //console.log(res.status);
            let value = Object.values(res.data.user)
            let played = value.at(0).played
            if (played === "True") {
              console.log("User has already played this Wordle.")
              setUserNotPlayedWordle(false)
            } else{
              console.log("User can play this Wordle.")
              setUserNotPlayedWordle(true)
              //navigate("/wordle");
            }
        }).catch((error) => {
          //console.log(error)
          setUserNotPlayedWordle(true)  
          console.log(error.message)
        });
  } 

  useEffect(() => {
      if (loaded){
        getIfNextBetExists()
        getIfUserAlreadyPlayedThisWordle()
        getIfTodayBetExists()
      }
  }, [loaded]);

  useEffect(() => {
    if (loaded){
      if (betNextExists){
        getDateNextBet()
        console.log("Next bet exists") 
        getIfUserAlreadyInNextBet()
      } else{
        console.log("Post next bet")
        postNextBet()
      }
      
    }
  }, [betNextExists]);

  useEffect(() => {
    if (loaded){
      if (betTodayExists) {
        //navigate("/wordle")
        getIfUserAlreadyInTodayBet()
      }
    }
  }, [betTodayExists]);
  useEffect(() => {
    if (loaded){
      if (betTodayExists && userInTodayBet && userNotPlayedWordle) {
        navigate("/wordle")
      }
    }
  }, [userInTodayBet]);

  return userInNextBet ? (
    <div className="center" ><JoinedWordle betDate={nextBetDate}/></div> 
  ) : (
    <div className="center" ><JoinWordleBet setUserInBet={setUserInNextBet} betDate={nextBetDate}/></div>
  );
}
export default HomeWordle;