import './wordle.css'
import { Navigate, useNavigate } from "react-router-dom";
import React, { useEffect, useState } from "react";
import { startPayment } from "../send-eth/SendETH";
import { ethers } from "ethers";
import { checkIfWalletIsConnected } from "../metamask-auth/connect";
import { addressWordleETH, AmountETH, HostPath, passwordAuthorized, userAuthorized } from "../../constants/constants";
import "animate.css/animate.min.css";
import { ToastContainer, toast, cssTransition } from "react-toastify";
import { Container } from '@material-ui/core';
import axios from 'axios';


const bounce = cssTransition({
    enter: "animate__animated animate__bounceIn",
    exit: "animate__animated animate__bounceOut"
});

function JoinWordleBet({ setUserInBet, betDate }) {
    const navigate = useNavigate();
    const [error, setError] = useState();
    const [txs, setTxs] = useState([]);

    const [userAddress, setUserAddress] = useState("");
    const [loaded, setLoaded] = useState(false);
    const [users, setUsers] = useState();

    const [loading, setLoading] = useState(false);

    const getUsersBet = async () => {
        const path = HostPath.path + 'bet'
        await axios.get(path)
            .then(res => {
                console.log(res.data)
                console.log(res.status);
                let value = Object.values(res.data.bet)
                let users = value.at(0).users
                setUsers(users)
                console.log(users)
            }).catch((error) => {
                console.log(error.message)
            });
      } 

    useEffect(()=>{
        if (error !== undefined){
            console.log(error)
            toast.dark(error, {transition: bounce});
        }
    },[error])
    
    useEffect(()=>{
        if (txs.length > 0){
            console.log(txs)
            toast.dark("Successful transaction!", {transition: bounce});
            // put 
            setLoading(true)
            putUserInNextBet()
        }
    },[txs])

    useEffect(() => {
      checkIfWalletIsConnected(setUserAddress);
      // checked when the page loads the first time
      //getUsersBet();
      //getWordleWordDay("castellano")
    }, []);

    useEffect(() => {
      if (userAddress!==""){
        try{
          console.log(userAddress)
          ethers.utils.getAddress(userAddress);
          setLoaded(true)
        } catch (err) {
          Navigate("/");
        }
      }
    }, [userAddress]);

    useEffect(() => {
        
    }, [loaded]); 
    
    const handleSubmit = async () => {
        if (loaded){
            await startPayment({
                setError,
                setTxs,
                ether: AmountETH.toString(),
                addr: addressWordleETH
            });
        }
    }

    useEffect(() => {
        setTimeout(function () { 
            //navigate("/wordle");
        }, 5000);
    }, []);
    
    const putUserInBet = async () => {
        const path = HostPath.path + 'bet'
        const parameters = {
            user: userAddress
        };
        console.log(parameters)
        await axios.put(path, parameters)
            .then(res => {
                console.log(res.data)
                console.log(res.status);
                if (res.status === 200) { // respuesta server is ok
                    console.log('¡Todo bien!')
                    setTimeout(function () { 
                        setUserInBet(true)
                    }, 3000);
                }else {
                    console.log("¡Algo ha ocurrido!");
                    setUserInBet(false)
                }
            }).catch((error) => {
                console.log(error.message)
            });
    }

    const putUserInNextBet = async () => {
        const path = HostPath.path + 'bet/date/' + 'next'
        const parameters = {
            user: userAddress
        };
        console.log(parameters)
        await axios.put(path, parameters, {
            auth: {
              username: userAuthorized,
              password: passwordAuthorized
            }
          })
            .then(res => {
                console.log(res.data)
                console.log(res.status);
                if (res.status === 200) { // respuesta server is ok
                    console.log('User addded to next bet')
                    setTimeout(function () { 
                        setUserInBet(true)
                    }, 3000);
                }else {
                    console.log("An error occurred while updating the list of users of the following bet.");
                    setUserInBet(false)
                }
            }).catch((error) => {
                console.log(error.message)
            });
    }
    
    return (
        <Container>
            <ToastContainer className="toast" transition={bounce} />
            <button className="button" onClick={() => handleSubmit()} disabled={loading}>
                Join Wordle {betDate}
            </button>
        </Container>
    );
}
export default JoinWordleBet;