import * as React from 'react';
import CssBaseline from '@mui/material/CssBaseline';
import Container from '@mui/material/Container';
import {createTheme, ThemeProvider} from '@mui/material/styles';
import Paper from "@mui/material/Paper";
import Header from '../component/header/header';
import { useLocation } from 'react-router-dom';
import HomeWordle from '../component/wordle/HomeWordle';
import { HostPath, passwordAuthorized, userAuthorized } from '../constants/constants';
import axios from 'axios';

const themeLight = createTheme({
    palette: {
        background: {
            default: "#FDF1D7"
        }
    }
});

const themeDark = createTheme({
    palette: {
        background: {
            default: "#2D2D2D"
        },
        text: {
            primary: "#FAF8FF"
        }
    }
});

export default function Home() {

    const [light, setLight] = React.useState(true);
    const location = useLocation();
    //console.log(location.state.address)

    const getWordleWordDay = async(language) => {
        const path = HostPath.path + 'wordle-word/language/' + language
        let word = ""
        await axios.get(path, {
            auth: {
              username: userAuthorized,
              password: passwordAuthorized
            }
          })
            .then(res => {
                //console.log(res.data)
                console.log(res.status);
                let value = Object.values(res.data.word)
                word = value.at(0).word
                // console.log(word)
    
            }).catch((error) => {
                console.log(error.message)
            });
    } 

    React.useEffect(() => {
        getWordleWordDay("castellano")
    }, []);

    return (
        <ThemeProvider theme={light ? themeLight : themeDark}>
            <CssBaseline/>
            <Container maxWidth="lg" style={{paddingBottom: "3em"}}>
                <Header/>
                <HomeWordle/>
            </Container>
        </ThemeProvider>
    );
}