import React, { useEffect, useState } from "react";
import CssBaseline from '@mui/material/CssBaseline';
import Container from '@mui/material/Container';
import {createTheme, ThemeProvider} from '@mui/material/styles';
import Paper from "@mui/material/Paper";
import Header from '../component/header/header';
import { Navigate, useLocation, useNavigate } from 'react-router-dom';
import HomeWordle from '../component/wordle/HomeWordle';
import { addressWordleETH, AmountETH, AmountETHMultiplayer, HostPath, passwordAuthorized, userAuthorized } from '../constants/constants';
import axios from 'axios';
import RequestObtainCrypto from "../component/obtain-crypto/RequestObtainCrypto";
import RequestedObtainCrypto from "../component/obtain-crypto/RequestedObtainCrypto";
import { checkIfWalletIsConnected } from "../component/metamask-auth/connect";
import { ethers } from "ethers";
import { Box } from "@material-ui/core";
import { ListItem } from "@mui/material";
import { startPayment } from "../component/send-eth/SendETH";
import { cssTransition, toast, ToastContainer } from "react-toastify";


const bounce = cssTransition({
    enter: "animate__animated animate__bounceIn",
    exit: "animate__animated animate__bounceOut"
});

const themeLight = createTheme({
    palette: {
        background: {
            default: "#FDF1D7"
        }
    }
});

const themeDark = createTheme({
    palette: {
        background: {
            default: "#2D2D2D"
        },
        text: {
            primary: "#FAF8FF"
        }
    }
});

export default function Multiplayer() {

    const [light, setLight] = React.useState(true);
    const location = useLocation();

    const [userAddress, setUserAddress] = useState("");
    const [loaded, setLoaded] = useState(false);
    const navigate = useNavigate();

    const [roomID, setRoomID] = useState();

    const [error, setError] = useState();
    const [txs, setTxs] = useState([]);
    const [loading, setLoading] = useState(false);


    useEffect(()=>{
        if (error !== undefined){
            console.log(error)
            toast.dark(error, {transition: bounce});
        }
    },[error])
    
    useEffect(()=>{
        if (txs.length > 0){
            console.log(txs)
            toast.dark("Successful transaction!", {transition: bounce});
            setLoading(true)
            postNewRoom()
        }
    },[txs])

    useEffect(() => {
        checkIfWalletIsConnected(setUserAddress);
    }, []);

    useEffect(() => {
        if (userAddress!==""){
            try{
                console.log(userAddress)
                ethers.utils.getAddress(userAddress);
                setLoaded(true)
            } catch (err) {
                Navigate("/");
            }
        }
    }, [userAddress]);

    useEffect(() => {
        if (loaded){
            //getIfUser...
        }
    }, [loaded]);

    const postNewRoom = async () => {
        const path = HostPath.path + 'room'
        const parameters = {
          amount_eth: AmountETH,
          host: userAddress
        };
        console.log(parameters)
        await axios.post(path, parameters, {
            auth: {
              username: userAuthorized,
              password: passwordAuthorized
            }
          })
            .then(res => {
                //console.log(res.data.id)
                //console.log(res.status);
                if (res.status === 201) { // respuesta server is ok
                    console.log('post Room success')
                    var rID = Object.values(res.data.room).at(0).id
                    console.log(rID)
                    setTimeout(function () { 
                        setRoomID(rID)
                    }, 5000);
                }else {
                  console.log("post Room failed");
                }
            }).catch((error) => {
                console.log(error.message)
            });
    } 

    const handleSubmit = async () => {
        // make transaction and if success:
        await startPayment({
            setError,
            setTxs,
            ether: AmountETHMultiplayer.toString(),
            addr: addressWordleETH
        });
            // post room
            // get room ID and set it
            //navigate("/wordle-multiplayer", {state:{roomID: roomID}}) // <- pass roomID created
    }

    useEffect(() => {
        if (roomID){
            navigate("/wordle-multiplayer", {state:{roomID: roomID}}) // <- pass roomID created
        }
    }, [roomID]);



    return (
        <ThemeProvider theme={light ? themeLight : themeDark}>
            <CssBaseline/>
            <Container maxWidth="lg" style={{height: "100vh"}}>
                <Header/>
                <ToastContainer className="toast" transition={bounce} />
                <div className="center" >
                <Box
                    sx={{
                    display: 'flex',
                    alignItems: 'center',
                    flexDirection: 'column',
                    justifyContent: 'center',
                    p: 1,
                    m: 1,
                    borderRadius: 1,
                    paddingTop:120
                    }}
                >
                    <div style={{marginBottom: "20vh"}}>
                        <button className="button" onClick={() => handleSubmit()} disabled={loading}>
                            Create Room
                        </button>
                    </div>
                    <button className="button" onClick={() => navigate("/join-room")} disabled={loading}>
                        Join Room
                    </button>

                </Box>
                </div> 
            </Container>
        </ThemeProvider>
    );
}