import React, { useEffect, useState } from "react";
import CssBaseline from '@mui/material/CssBaseline';
import Container from '@mui/material/Container';
import {createTheme, ThemeProvider} from '@mui/material/styles';
import Paper from "@mui/material/Paper";
import Header from '../component/header/header';
import { Navigate, useLocation } from 'react-router-dom';
import HomeWordle from '../component/wordle/HomeWordle';
import { HostPath } from '../constants/constants';
import axios from 'axios';
import RequestObtainCrypto from "../component/obtain-crypto/RequestObtainCrypto";
import RequestedObtainCrypto from "../component/obtain-crypto/RequestedObtainCrypto";
import { checkIfWalletIsConnected } from "../component/metamask-auth/connect";
import { ethers } from "ethers";

const themeLight = createTheme({
    palette: {
        background: {
            default: "#FDF1D7"
        }
    }
});

const themeDark = createTheme({
    palette: {
        background: {
            default: "#2D2D2D"
        },
        text: {
            primary: "#FAF8FF"
        }
    }
});

export default function ObtainCrypto() {

    const [light, setLight] = React.useState(true);
    const location = useLocation();
    const [userAlreadyRequested, setUserAlreadyRequested] = useState();
    const [requestDate, setRequestDate] = useState();
    const [userAddress, setUserAddress] = useState("");
    const [loaded, setLoaded] = useState(false);
    //console.log(location.state.address)

    const getIfUserRequested = async () => {
        const path = HostPath.path + 'obtain-crypto/address/' + userAddress
        await axios.get(path)
            .then(res => {
                if (res.status === 200){
                    let value = Object.values(res.data.user_request)
                    let date = value.at(0).date
                    setRequestDate(date)
                    setUserAlreadyRequested(true)
                }
            }).catch((error) => {
                console.log(error.message)
                if (error.status === 404){
                    setUserAlreadyRequested(false)
                }
            });
    } 


    useEffect(() => {
        checkIfWalletIsConnected(setUserAddress);
    }, []);

    useEffect(() => {
        if (userAddress!==""){
            try{
                console.log(userAddress)
                ethers.utils.getAddress(userAddress);
                setLoaded(true)
            } catch (err) {
                Navigate("/");
            }
        }
    }, [userAddress]);

    useEffect(() => {
        if (loaded){
            getIfUserRequested()
            //console.log(userAlreadyRequested)
        }
    }, [loaded]);

    return (
        <ThemeProvider theme={light ? themeLight : themeDark}>
            <CssBaseline/>
            <Container maxWidth="lg" style={{paddingBottom: "3em"}}>
                <Header/>
                <div className="center" >
                    {!userAlreadyRequested && <RequestObtainCrypto setUserAlreadyRequested={setUserAlreadyRequested} userAlreadyRequested={userAlreadyRequested} setRequestDate={setRequestDate}/>}
                    {userAlreadyRequested && <RequestedObtainCrypto requestDate={requestDate}/>}
                </div>
            </Container>
        </ThemeProvider>
    );
}