import React, { useEffect, useState } from "react";
import AppBar from '@mui/material/AppBar';
import Button from '@mui/material/Button';
import CameraIcon from '@mui/icons-material/PhotoCamera';
import Card from '@mui/material/Card';
import CardActions from '@mui/material/CardActions';
import CardContent from '@mui/material/CardContent';
import CardMedia from '@mui/material/CardMedia';
import CssBaseline from '@mui/material/CssBaseline';
import Grid from '@mui/material/Grid';
import Stack from '@mui/material/Stack';
import Box from '@mui/material/Box';
import Toolbar from '@mui/material/Toolbar';
import Typography from '@mui/material/Typography';
import Container from '@mui/material/Container';
import Link from '@mui/material/Link';
import { createTheme, ThemeProvider } from '@mui/material/styles';
import Header from '../component/header/header';
import { Navigate, useLocation } from 'react-router-dom';
import { addressWordleETH, HostPath, passwordAuthorized, userAuthorized } from "../constants/constants";
import axios from "axios";
import { startPayment } from "../component/send-eth/SendETH";
import { cssTransition, toast, ToastContainer } from "react-toastify";
import { checkIfWalletIsConnected } from "../component/metamask-auth/connect";
import { ethers } from "ethers";

const bounce = cssTransition({
    enter: "animate__animated animate__bounceIn",
    exit: "animate__animated animate__bounceOut"
});


function Copyright() {
  return (
    <Typography variant="body2" color="text.secondary" align="center">
      {'Copyright © '}
      <Link color="inherit" href="https://mui.com/">
        Your Website
      </Link>{' '}
      {new Date().getFullYear()}
      {'.'}
    </Typography>
  );
}

const cards = [1, 2, 3, 4, 5, 6, 7, 8, 9];

const theme = createTheme();

const themeWordleCrypto = createTheme({
    palette: {
        background: {
            default: "#FDF1D7"
        }
    }
});

const themeWordleCryptoDark = createTheme({
    palette: {
        background: {
            default: "#0A1A29"
        }
    }
});

export default function Store() {
    const location = useLocation();
    //console.log(location.state.address)
    const [themes, setThemes] = useState();
    const [userThemes, setUserThemes] = useState([]);

    const [error, setError] = useState();
    const [txs, setTxs] = useState([]);
    const [themeToBuy, setThemeToBuy] = useState()

    const [userAddress, setUserAddress] = useState("");
    const [loaded, setLoaded] = useState(false);

    useEffect(() => {
        if(!window.location.hash) {
            window.location = window.location + '#loaded';
            window.location.reload();
        }
        checkIfWalletIsConnected(setUserAddress);
        // checked when the page loads the first time
        //getUsersBet();
    }, []);
  
    useEffect(() => {
        if (userAddress!==""){
            try{
                console.log(userAddress)
                ethers.utils.getAddress(userAddress);
                setLoaded(true)
            } catch (err) {
                Navigate("/");
            }
        }
    }, [userAddress]);

    useEffect(()=>{
        if (error !== undefined){
            console.log(error)
            toast.dark(error, {transition: bounce});
        }
    },[error])
    
    useEffect(()=>{
        if (txs.length > 0){
            console.log(txs)
            toast.dark("Successful transaction!", {transition: bounce});
            putUserTheme(themeToBuy)
            setTxs([])
            setThemeToBuy(undefined)
        }
    },[txs])

    const getThemes = async () => {
        const path = HostPath.path + 'themes'
        await axios.get(path)
            .then(res => {
                console.log(res.data)
                console.log(res.status);
                setThemes(res.data.themes)
            }).catch((error) => {
                console.log(error.message)
            });
    } 

    const getUserThemes = async () => {
        const path = HostPath.path + 'user/address/' + userAddress
        await axios.get(path)
            .then(res => {
                //console.log(res.data)
                //console.log(res.status);
                let value = Object.values(res.data.user)
                let themes = value.at(0).themes
                setUserThemes(themes)
                console.log(themes)
            }).catch((error) => {
                console.log(error.message)
            });
    } 

    useEffect(() => {
        getThemes()
        getUserThemes()
    }, [loaded]);

    const onClickHandler = async(theme) => {
        console.log("Buy " + theme.id)
        setThemeToBuy(theme.id)
        await startPayment({
            setError,
            setTxs,
            ether: theme.priceETH.toString(),
            addr: addressWordleETH
        });
    }

    const putUserTheme = async (themeId) => {
        const path = HostPath.path + 'user'
        const parameters = {
            address: userAddress,
            theme: themeId
        };
        console.log(parameters)
        await axios.put(path, parameters, {
            auth: {
              username: userAuthorized,
              password: passwordAuthorized
            }
          })
            .then(res => {
                console.log(res.data)
                console.log(res.status);
                if (res.status === 200) { // respuesta server is ok
                    console.log('Theme added to user themes list succesfuly.')
                    setTimeout(function () { 
                        //setUserInBet(true)
                        getUserThemes()
                    }, 2000);
                }else {
                    console.log("Something goes wrong!");
                    //setUserInBet(false)
                }
            }).catch((error) => {
                console.log(error.message)
            });
    }

    return (
        <ThemeProvider theme={themeWordleCrypto}>
        <CssBaseline />
        <Header userAddress={''}/>
        <ToastContainer className="toast" transition={bounce} />
        <main>
            {/* Hero unit */}
            <Box
            sx={{
                pt: 8,
                pb: 3,
                marginTop: 6,
            }}
            >
            <Container maxWidth="sm">
                <Typography
                component="h1"
                variant="h2"
                align="center"
                color="#0A1A29"
                >
                Themes Store
                </Typography>
            </Container>
            </Box>
            <Container sx={{ py: 4 }} maxWidth="md">
            {/* End hero unit */}
            {themes && <Grid container spacing={4}>
                {Object.values(themes).map((theme) => (
                <Grid item key={theme.id} xs={12} sm={6} md={4}>
                    <Card
                    sx={{ height: '19em', display: 'flex', flexDirection: 'column', backgroundColor: '#0A1A29'}}
                    >
                    <CardMedia
                        component="picture"
                        sx={{
                            pt: '0%',
                            height: '70%',
                        }}
                        style={{backgroundColor: theme.color}}
                    />
                    <CardContent sx={{paddingY:0, marginTop: 1}}>
                        <Typography align='center' variant="h5" component="h2" marginBottom={0} paddingBottom={0} color={'#ffffff'}>
                        {theme.name}
                        </Typography>
                    </CardContent>
                    <CardActions style={{justifyContent: 'center'}}>
                    {!userThemes.includes(theme.id)  && <Button  variant="contained" size="small" onClick={() => onClickHandler(theme)} sx={{backgroundColor: '#e5771b'}}>Buy {theme.priceETH} ETH</Button>}
                    {userThemes.includes(theme.id)  && <Button variant="contained" size="small">Bought</Button>}
                    </CardActions>
                    </Card>
                </Grid>
                ))}
            </Grid>}
            </Container>
        </main>
        {/* Footer */}
        <Box sx={{ p: 6 }} component="footer">
            <Typography variant="h6" align="center" gutterBottom>
            Footer
            </Typography>
            <Typography
            variant="subtitle1"
            align="center"
            color="text.secondary"
            component="p"
            >
            Something here to give the footer a purpose!
            </Typography>
            <Copyright />
        </Box>
        {/* End footer */}
        </ThemeProvider>
    );
}