import * as React from 'react';
import { useEffect, useState } from "react";
import CssBaseline from '@mui/material/CssBaseline';
import Container from '@mui/material/Container';
import {createTheme, ThemeProvider} from '@mui/material/styles';
import Paper from "@mui/material/Paper";
import Header from '../component/header/header';
import { Navigate, useLocation, useNavigate } from 'react-router-dom';
import HomeWordle from '../component/wordle/HomeWordle';
import Wordle from '../component/wordle/Wordle';
import { Box } from '@material-ui/core';
import { checkIfWalletIsConnected } from '../component/metamask-auth/connect';
import { ethers } from 'ethers';
import { HostPath } from '../constants/constants';
import axios from 'axios';


const theme = createTheme();

export default function WordleGame() {

  const [light, setLight] = React.useState(true);
  const location = useLocation();
  //console.log(location.state.address)
  const [userInBet, setUserInBet] = useState();
  const [betExists, setBetExists] = useState();
  const [userAddress, setUserAddress] = useState("");
  const [loaded, setLoaded] = useState(false);
  const navigate = useNavigate();

  useEffect(() => {
      checkIfWalletIsConnected(setUserAddress);
      // checked when the page loads the first time
    }, []);
  
  useEffect(() => {
    if (userAddress!==""){
      try{
        // console.log(userAddress)
        ethers.utils.getAddress(userAddress);
        setLoaded(true)
      } catch (err) {
        Navigate("/");
      }
    }
  }, [userAddress]);
  
  const getIfBetExists = async () => {
    const path = HostPath.path + 'bet'
    await axios.get(path)
        .then(res => {
            //console.log(res.data)
            //console.log(res.status);
            setBetExists(true)
        }).catch((error) => {
            console.log(error.message)
            setBetExists(false)
        });
  }
    
  const getIfUserAlreadyInBet = async () => {
    const path = HostPath.path + 'bet'
    await axios.get(path)
        .then(res => {
            //console.log(res.data)
            //console.log(res.status);
            let value = Object.values(res.data.bet)
            let users = value.at(0).users
            if (users.includes(userAddress)) {
              setUserInBet(true)
              console.log("User is already in today's bet.")
            }else{
              setUserInBet(false)
              console.log("User isn't already in this bet.")
              navigate("/home");
            }
        }).catch((error) => {
            console.log(error.message)
        });
  } 

  const getIfUserAlreadyPlayedThisWordle = async () => {
    const path = HostPath.path + 'wordle-spanish/address/' + userAddress
    console.log(path)
    await axios.get(path)
        .then(res => {
            //console.log(res.data)
            //console.log(res.status);
            let value = Object.values(res.data.user)
            let played = value.at(0).played
            if (played === "True") {
              console.log("User has already played this Wordle.")
              navigate("/home");
            } else{
              console.log("User can play this Wordle.")
            }
        }).catch((error) => {
          //console.log(error)
          console.log(error.message)
        });
  } 
    
  useEffect(() => {
      if (loaded){
        getIfBetExists()
      }
  }, [loaded]);

  useEffect(() => {
    if (loaded){
      if (betExists){
        console.log("Bet exists") 
        getIfUserAlreadyInBet()
      } else{
        navigate("/home");
      }
    }
  }, [betExists]);

  useEffect(() => {
    if (loaded && betExists && userInBet){
      // check if user already played today's Wordle
      getIfUserAlreadyPlayedThisWordle()
    }
  }, [userInBet]);
    

  return (
      <ThemeProvider theme={theme}>
          <Header/>
          <Box
              sx={{
              mx: 'auto',
              height: '90%',
              p: 1,
              paddingTop: '70px'
              }}
          >
              <Wordle />
          </Box>
      </ThemeProvider>
  );
} 