import React, { useEffect, useState } from "react";
import CssBaseline from '@mui/material/CssBaseline';
import Container from '@mui/material/Container';
import {createTheme, ThemeProvider} from '@mui/material/styles';
import Paper from "@mui/material/Paper";
import Header from '../component/header/header';
import { Navigate, useLocation, useNavigate } from 'react-router-dom';
import SendETH from '../component/send-eth/SendETH';
import '../component/metamask-auth/login-metamask.css';
import CreateRoom from '../component/multiplayer/CreateRoom';
import WaitingRoom from '../component/multiplayer/WaitingRoom';
import { Box } from '@material-ui/core';
import { checkIfWalletIsConnected } from "../component/metamask-auth/connect";
import { ethers } from "ethers";
import PropTypes from 'prop-types';
import { HostPath, WordleEthereumAddress, AmountETHMultiplayer, addressWordleETH, userAuthorized, passwordAuthorized} from "../constants/constants";
import axios from "axios";
import WordleMultiplayer from "../component/multiplayer/WordleMultiplayer";

const theme = createTheme();

const themeWordleCrypto = createTheme({
    palette: {
        background: {
            default: "#FDF1D7"
        }
    }
});

const themeDark = createTheme({
    palette: {
        background: {
            default: "#2D2D2D"
        },
        text: {
            primary: "#FAF8FF"
        }
    }
});

export default function WordleGameMultiplayer({props}) {

    const [light, setLight] = React.useState(true);
    const location = useLocation();

    const [roomState, setRoomState] = React.useState();
    const [started, setRoomStarted] = React.useState();
    const [userIsHost, setUserIsHost] = React.useState(false);

    const [userAddress, setUserAddress] = useState("");
    const [loaded, setLoaded] = useState(false);
    const navigate = useNavigate();
    const [roomID, setRoomID] = useState();
    const [userInRoom, setUserInRoom] = useState();

    const getRoomData = async () => {
        const path = HostPath.path + 'room/id/' + roomID
        await axios.get(path, {
            auth: {
              username: userAuthorized,
              password: passwordAuthorized
            }
          })
            .then(res => {
                //console.log(res.data)
                //console.log(res.status);
                let value = Object.values(res.data.room)
                let users = Object.keys(value.at(0).users)
                var host = value.at(0).host
                var startedRoom = value.at(0).started
                if (users.includes(userAddress)) {
                  setUserInRoom(true)
                  setUserIsHost(host===userAddress)
                  setRoomStarted(startedRoom)
                }else{
                  setUserInRoom(false)
                }
            }).catch((error) => {
                console.log(error.message)
            });
    } 

    useEffect(() => {
        checkIfWalletIsConnected(setUserAddress);
    }, []);

    useEffect(() => {
        if (userAddress!==""){
            try{
                console.log(userAddress)
                ethers.utils.getAddress(userAddress);
                setLoaded(true)
            } catch (err) {
                Navigate("/");
            }
        }
    }, [userAddress]);

    useEffect(() => {
        if (loaded){
            setRoomID(location.state.roomID)
            // check is the game has started
        }
    }, [loaded]);

    useEffect(() => {
        if (loaded && roomID){
            console.log(roomID)
            // check another time if user is in the room, if user is host or not and if the game have started
            getRoomData()
        }
    }, [roomID]);

    useEffect(() => {
        if (loaded && roomID){
            if (userInRoom){
                console.log("User is already in this room.")
            } else {
                console.log("User isn't already in this room.")
                navigate("/multiplayer");
            }
        }
    }, [userInRoom]);

    useEffect(() => {
        if (loaded && roomID){
            if (userIsHost){
                console.log("User is the host.")
            } else {
                console.log("User isn't the host.")
            }
        }
    }, [userIsHost]);

    useEffect(() => {
        if (loaded && roomID){
            if (started){
                console.log("The Wordle Multiplayer has already started.")
            } else {
                console.log("The Wordle Multiplayer hasn't started.")
            }
        }
    }, [started]);

    return (
        <ThemeProvider theme={theme}>
            <Header userAddress={''}/>
            {started===false && <Box
                sx={{
                mx: 'auto',
                height: '90%',
                display: 'flex',
                justifyContent: 'center',
                p: 1,
                paddingTop: '70px',
                background: "#FDF1D7"
                }}
            >
                 <div style={{marginTop: "150px", maxWidth: "500px"}}>
                    <WaitingRoom userIsHost={userIsHost} roomID={roomID}/>
                </div>
                </Box>}
            {started && <Box
                sx={{
                mx: 'auto',
                height: '90%',
                p: 1,
                paddingTop: '70px',
                //background: "#FDF1D7"
                }}
            >
                <WordleMultiplayer roomID={roomID} navigate={navigate}/>
            </Box>}
            
        </ThemeProvider>
    );
}